@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -66,10 +66,11 @@
 #define MOD_CFG_SATS_KEY        "SATELLITES"
 #define MOD_CFG_TIMEOUT_KEY     "TIMEOUT"
 #define MOD_CFG_WARP_KEY        "WARP"
-#define MOD_CFG_LAYOUT          "LAYOUT"
-#define MOD_CFG_VIEW_1          "VIEW_1"
-#define MOD_CFG_VIEW_2          "VIEW_2"
-#define MOD_CFG_VIEW_3          "VIEW_3"
+#define MOD_CFG_LAYOUT          "LAYOUT"      /* Old layout before v1.2 */
+#define MOD_CFG_VIEW_1          "VIEW_1"      /* Old layout before v1.2 */
+#define MOD_CFG_VIEW_2          "VIEW_2"      /* Old layout before v1.2 */
+#define MOD_CFG_VIEW_3          "VIEW_3"      /* Old layout before v1.2 */
+#define MOD_CFG_GRID            "GRID"        /* New grid layout since v1.2 */
 #define MOD_CFG_STATE           "STATE"
 #define MOD_CFG_WIN_POS_X       "WIN_POS_X"
 #define MOD_CFG_WIN_POS_Y       "WIN_POS_Y"
@@ -101,6 +102,7 @@
 #define MOD_CFG_MAP_TRACK_COL        "TRACK_COLOUR"
 #define MOD_CFG_MAP_TRACK_NUM        "TRACK_NUMBER"
 #define MOD_CFG_MAP_KEEP_RATIO       "KEEP_RATIO"
+#define MOD_CFG_MAP_SHADOW_ALPHA     "SHADOW_ALPHA"
 
 /* polar view specific */
 #define MOD_CFG_POLAR_SECTION          "POLAR"
@@ -126,4 +128,9 @@
 #define MOD_CFG_SINGLE_SAT_REFRESH "REFRESH"
 #define MOD_CFG_SINGLE_SAT_FIELDS  "FIELDS"
 
+/* event list */
+#define MOD_CFG_EVENT_LIST_SECTION  "EVENT_LIST"
+#define MOD_CFG_EVENT_LIST_REFRESH "REFRESH"
+
+
 #endif
