@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2010  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -201,7 +201,7 @@ first_time_check_step_02 (guint *error)
                 so we must not free it
             */
 
-            if (g_strrstr (datafile, ".qth")) {
+            if (g_str_has_suffix (datafile, ".qth")) {
                 foundqth = TRUE;
             }
 
@@ -227,7 +227,7 @@ first_time_check_step_02 (guint *error)
                     /* note: filename is not a newly allocated gchar *,
                        so we must not free it
                     */
-                    if (g_strrstr (datafile, ".qth")) {
+                    if (g_str_has_suffix (datafile, ".qth")) {
 
                         gchar *source = g_strconcat (olddir, G_DIR_SEPARATOR_S, datafile, NULL);
 
@@ -342,7 +342,7 @@ first_time_check_step_03 (guint *error)
                     /* note: filename is not a newly allocated gchar *,
                        so we must not free it
                     */
-                    if (g_strrstr (datafile, ".mod")) {
+                    if (g_str_has_suffix (datafile, ".mod")) {
                         gchar *source = g_strconcat (olddir, G_DIR_SEPARATOR_S, datafile, NULL);
 
                         /* copy .qth file to USER_CONF_DIR */
@@ -606,7 +606,7 @@ first_time_check_step_05 (guint *error)
             /* note: filename is not a newly allocated gchar *,
                 so we must not free it
             */
-            if (g_strrstr (filename, ".cat")) {
+            if (g_str_has_suffix (filename, ".cat")) {
 
                 /* check whether .cat file exisits in user conf */
                 gchar *catfilename = sat_file_name (filename);
@@ -626,6 +626,7 @@ first_time_check_step_05 (guint *error)
                     }
                     g_free (source);
                 }
+                    g_free (catfilename);
             }
         }
         g_dir_close (srcdir);
@@ -849,40 +850,45 @@ static void first_time_check_step_09 (guint *error)
         g_free (buff);
         dir = g_dir_open (datadirname, 0, NULL);
         
-        /* for each .trsp file found in data dir */
-        while ((filename = g_dir_read_name (dir))) {
-            if (g_strrstr (filename, ".trsp")) {
-                /* check if .trsp file already in user dir */
-                destfile = g_strconcat (targetdirname, G_DIR_SEPARATOR_S, filename, NULL);
-                
-                /* check if .trsp file already in user dir */
-                if (!g_file_test (destfile, G_FILE_TEST_EXISTS)) {
-                    sat_log_log (SAT_LOG_LEVEL_MSG,
-                                 _("%s: %s does not appear to be in user conf dir; adding."),
-                                 __FUNCTION__, filename);
-
-                                 /* copy new .trsp file to user dir */
-                    srcfile = g_strconcat (datadirname, G_DIR_SEPARATOR_S, filename,NULL);
-                    if (gpredict_file_copy (srcfile, destfile)) {
-                        sat_log_log (SAT_LOG_LEVEL_ERROR, 
-                                     _("%s: Failed to copy %s"),
+        if (dir) {
+            /* for each .trsp file found in data dir */
+            while ((filename = g_dir_read_name (dir))) {
+                if (g_str_has_suffix (filename, ".trsp")) {
+                    /* check if .trsp file already in user dir */
+                    destfile = g_strconcat (targetdirname, G_DIR_SEPARATOR_S, filename, NULL);
+                    
+                    /* check if .trsp file already in user dir */
+                    if (!g_file_test (destfile, G_FILE_TEST_EXISTS)) {
+                        sat_log_log (SAT_LOG_LEVEL_MSG,
+                                     _("%s: %s does not appear to be in user conf dir; adding."),
                                      __FUNCTION__, filename);
 
-                        *error |= FTC_ERROR_STEP_09;
+                        /* copy new .trsp file to user dir */
+                        srcfile = g_strconcat (datadirname, G_DIR_SEPARATOR_S, filename,NULL);
+                        if (gpredict_file_copy (srcfile, destfile)) {
+                            sat_log_log (SAT_LOG_LEVEL_ERROR, 
+                                         _("%s: Failed to copy %s"),
+                                         __FUNCTION__, filename);
+
+                            *error |= FTC_ERROR_STEP_09;
+                        }
+                        g_free (srcfile);
                     }
-                    g_free (srcfile);
+                    else {
+                        sat_log_log (SAT_LOG_LEVEL_MSG,
+                                     _("%s: %s already in user conf dir."),
+                                     __FUNCTION__, filename);
+                    }
+                    
+                    g_free (destfile);
                 }
-                else {
-                    sat_log_log (SAT_LOG_LEVEL_MSG,
-                                 _("%s: %s already in user conf dir."),
-                                 __FUNCTION__, filename);
-                }
-                
-                g_free (destfile);
-            
             }
-        }
-        g_dir_close (dir);
+            g_dir_close (dir);
+        } else {
+               sat_log_log (SAT_LOG_LEVEL_ERROR,
+                               _("%s: %s directory does not exist. Incomplete installation."),
+                               __FUNCTION__, datadirname);
+          }
         g_free (datadirname);
     }
     g_free (targetdirname);
