@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -410,7 +410,7 @@ void gtk_polar_plot_set_rotor_pos (GtkPolarPlot *plot, gdouble az, gdouble el)
     
     root = goo_canvas_get_root_item_model (GOO_CANVAS (plot->canvas));
 
-    if ((az < 0.0) || (el <= 0.0)) {
+    if ((az < 0.0) || (el < 0.0)) {
         if (plot->rot1 != NULL) {
             /* the target object is visible; delete it */
             idx = goo_canvas_item_model_find_child (root, plot->rot1);
@@ -932,13 +932,15 @@ static void
 
     for (i = 1; i < num-1; i++) {
         detail = PASS_DETAIL(g_slist_nth_data (pv->pass->details, i));
-        azel_to_xy (pv, detail->az, detail->el, &x, &y);
+        if (detail->el >= 0.0)
+            azel_to_xy (pv, detail->az, detail->el, &x, &y);
         points->coords[2*i] = (double) x;
         points->coords[2*i+1] = (double) y;
 
         if (!(i % tres)) {
-            /* create a time tick */
-            pv->trtick[ttidx] = create_time_tick (pv, detail->time, x, y);
+            if (ttidx<TRACK_TICK_NUM)
+                /* create a time tick */
+                pv->trtick[ttidx] = create_time_tick (pv, detail->time, x, y);
             ttidx++;
         }
     }
@@ -1041,7 +1043,8 @@ static void
 
     for (i = 1; i < num-1; i++) {
         detail = PASS_DETAIL(g_slist_nth_data (pv->pass->details, i));
-        azel_to_xy (pv, detail->az, detail->el, &x, &y);
+        if (detail->el>=0.0)
+            azel_to_xy (pv, detail->az, detail->el, &x, &y);
         points->coords[2*i] = (double) x;
         points->coords[2*i+1] = (double) y;
 
@@ -1054,9 +1057,11 @@ static void
                 x += 5;
             }
             /* update time tick */
-            g_object_set (pv->trtick[ttidx],
-                          "x", (gdouble) x, "y", (gdouble) y,
-                          NULL);
+            if (ttidx<TRACK_TICK_NUM){
+                g_object_set (pv->trtick[ttidx],
+                              "x", (gdouble) x, "y", (gdouble) y,
+                              NULL);
+            }
             ttidx++;
         }
     }
@@ -1212,7 +1217,7 @@ static void
                          GooCanvasItemModel *model,
                          gpointer data)
 {
-    if (!goo_canvas_item_model_get_parent (model))	{
+    if (!goo_canvas_item_model_get_parent (model))     {
         /* root item / canvas */
         g_signal_connect (item, "motion_notify_event",
                           (GtkSignalFunc) on_motion_notify, data);
