@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -95,7 +95,7 @@ void
     /* attach data to menuitem and connect callback */
     g_object_set_data (G_OBJECT (menuitem), "sat", sat);
     g_object_set_data (G_OBJECT (menuitem), "qth", qth);
-    g_signal_connect (menuitem, "activate", G_CALLBACK (show_sat_info), toplevel);
+    g_signal_connect (menuitem, "activate", G_CALLBACK (show_sat_info_menu_cb), toplevel);
 
     gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
@@ -144,13 +144,13 @@ void
         gtk_widget_set_sensitive (menuitem, FALSE);
 
     /* target */
-    /* 	menuitem = gtk_check_menu_item_new_with_label (_("Set as target")); */
-    /* 	g_object_set_data (G_OBJECT (menuitem), "sat", sat); */
-    /* 	g_object_set_data (G_OBJECT (menuitem), "qth", qth); */
-    /* 	g_object_set_data (G_OBJECT (menuitem), "obj", obj); */
-    /* 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem); */
-    /* 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), obj->istarget); */
-    /* 	g_signal_connect (menuitem, "activate", G_CALLBACK (target_toggled), pview); */
+    /*      menuitem = gtk_check_menu_item_new_with_label (_("Set as target")); */
+    /*      g_object_set_data (G_OBJECT (menuitem), "sat", sat); */
+    /*      g_object_set_data (G_OBJECT (menuitem), "qth", qth); */
+    /*      g_object_set_data (G_OBJECT (menuitem), "obj", obj); */
+    /*      gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem); */
+    /*      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), obj->istarget); */
+    /*      g_signal_connect (menuitem, "activate", G_CALLBACK (target_toggled), pview); */
 
     gtk_widget_show_all (menu);
 
@@ -210,6 +210,12 @@ static void
 
         /* create points */
         num = g_slist_length (obj->pass->details);
+        if (num == 0) {
+            sat_log_log (SAT_LOG_LEVEL_BUG,
+                         _("%s:%d: Pass has no details."),
+                         __FILE__, __LINE__);
+            return;
+        }
 
         /* time resolution for time ticks; we need
                    3 additional points to AOS and LOS ticks.
@@ -228,13 +234,15 @@ static void
 
         for (i = 1; i < num-1; i++) {
             detail = PASS_DETAIL(g_slist_nth_data (obj->pass->details, i));
-            azel_to_xy (pv, detail->az, detail->el, &x, &y);
+            if (detail->el >=0.0)
+                azel_to_xy (pv, detail->az, detail->el, &x, &y);
             points->coords[2*i] = (double) x;
             points->coords[2*i+1] = (double) y;
 
             if (!(i % tres)) {
                 /* create a time tick */
-                obj->trtick[ttidx] = create_time_tick (pv, detail->time, x, y);
+                if (ttidx<TRACK_TICK_NUM)
+                    obj->trtick[ttidx] = create_time_tick (pv, detail->time, x, y);
                 ttidx++;
             }
         }
