@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -40,6 +40,7 @@
 #include "gpredict-utils.h"
 #include "gtk-polar-view-popup.h"
 #include "gtk-polar-view.h"
+#include "sat-info.h"
 #ifdef HAVE_CONFIG_H
 #  include <build-config.h>
 #endif
@@ -47,7 +48,7 @@
 
 
 
-#define POLV_DEFAULT_SIZE 300
+#define POLV_DEFAULT_SIZE 100
 #define POLV_DEFAULT_MARGIN 25
 
 /* extra size for line outside 0 deg circle (inside margin) */
@@ -87,6 +88,7 @@ static gboolean on_button_release      (GooCanvasItem *item,
 static void clear_selection            (gpointer key, gpointer val, gpointer data);
 static GooCanvasItemModel* create_canvas_model (GtkPolarView *polv);
 static void get_canvas_bg_color        (GtkPolarView *polv, GdkColor *color);
+static gchar *los_time_to_str (GtkPolarView *polv, sat_t *sat);
 
 
 static GtkVBoxClass *parent_class = NULL;
@@ -236,12 +238,13 @@ gtk_polar_view_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 
     /* create the canvas */
     GTK_POLAR_VIEW (polv)->canvas = goo_canvas_new ();
+    g_object_set (G_OBJECT (GTK_POLAR_VIEW (polv)->canvas), "has-tooltip", TRUE, NULL);
     get_canvas_bg_color (GTK_POLAR_VIEW (polv), &bg_color);
     gtk_widget_modify_base (GTK_POLAR_VIEW (polv)->canvas, GTK_STATE_NORMAL, &bg_color);
     gtk_widget_set_size_request (GTK_POLAR_VIEW (polv)->canvas,
                                  POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
     goo_canvas_set_bounds (GOO_CANVAS (GTK_POLAR_VIEW (polv)->canvas), 0, 0,
-                                POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
+                           POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
 
 
     /* connect size-request signal */
@@ -791,6 +794,8 @@ update_sat    (gpointer key, gpointer value, gpointer data)
     gint               idx,i;
     gdouble            now;// = get_current_daynum ();
     gchar             *text;
+    gchar             *losstr;
+    gchar             *tooltip;
     guint32            colour;
 
 
@@ -869,78 +874,48 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 
         /* if sat is already on canvas */
         if (obj != NULL) {
-            /* update sat */
+
+            /* update LOS count down */
+            if (sat->los > 0.0) {
+                losstr = los_time_to_str(polv, sat);
+            }
+            else {
+                losstr = g_strdup_printf (_("%s\nAlways in range"), sat->nickname);
+            }
+
+            /* update tooltip */
+            tooltip = g_strdup_printf("<big><b>%s</b>\n</big>"\
+                                      "<tt>Az: %5.1f\302\260\n" \
+                                      "El: %5.1f\302\260\n" \
+                                      "%s</tt>",
+                                      sat->nickname,
+                                      sat->az, sat->el,
+                                      losstr);
+
             g_object_set (obj->marker,
                           "x", x - MARKER_SIZE_HALF,
                           "y", y - MARKER_SIZE_HALF,
+                          "tooltip", tooltip,
                           NULL);
             g_object_set (obj->label,
                           "x", x,
                           "y", y+2,
+                          "tooltip", tooltip,
                           NULL);
 
+            g_free (tooltip);
+
             /* update selection info if satellite is
                selected
             */
             if (obj->selected) {
-                guint         h,m,s;
-                gchar        *ch,*cm,*cs;
-                gdouble       number, now;
-
-                if (sat->los > 0.0) {
-                    now = polv->tstamp;//get_current_daynum ();
-                    number = sat->los - now;
-
-                    /* convert julian date to seconds */
-                    s = (guint) (number * 86400);
-
-                    /* extract hours */
-                    h = (guint) floor (s/3600);
-                    s -= 3600*h;
-
-                    /* leading zero */
-                    if ((h > 0) && (h < 10))
-                        ch = g_strdup ("0");
-                    else
-                        ch = g_strdup ("");
-
-                    /* extract minutes */
-                    m = (guint) floor (s/60);
-                    s -= 60*m;
-
-                    /* leading zero */
-                    if (m < 10)
-                        cm = g_strdup ("0");
-                    else
-                        cm = g_strdup ("");
-
-                    /* leading zero */
-                    if (s < 10)
-                        cs = g_strdup (":0");
-                    else
-                        cs = g_strdup (":");
-
-                    if (h > 0) {
-                        text = g_strdup_printf (_("%s\nLOS in %s%d:%s%d%s%d"),
-                                                sat->nickname, ch, h, cm, m, cs, s);
-                    }
-                    else {
-                        text = g_strdup_printf (_("%s\nLOS in %s%d%s%d"),
-                                                sat->nickname, cm, m, cs, s);
-                    }
-                    g_free (ch);
-                    g_free (cm);
-                    g_free (cs);
-                }
-                else {
-                    text = g_strdup_printf (_("%s\nAlways in range"), sat->nickname);
-                }
+                text = g_strdup_printf ("%s\n%s",sat->nickname, losstr);
                 g_object_set (polv->sel, "text", text, NULL);
-
                 g_free (text);
             }
 
-            g_free (catnum);
+            g_free (losstr);
+            g_free (catnum);  // FIXME: why free here, what about else?
         }
         else {
             /* add sat to canvas */
@@ -956,6 +931,14 @@ update_sat    (gpointer key, gpointer value, gpointer data)
                                       MOD_CFG_POLAR_SAT_COL,
                                       SAT_CFG_INT_POLAR_SAT_COL);
 
+            /* create tooltip */
+            tooltip = g_strdup_printf("<big><b>%s</b>\n</big>"\
+                                      "<tt>Az: %5.1f\302\260\n" \
+                                      "El: %5.1f\302\260\n" \
+                                      "</tt>",
+                                      sat->nickname,
+                                      sat->az, sat->el);
+
             obj->marker = goo_canvas_rect_model_new (root,
                                                      x - MARKER_SIZE_HALF,
                                                      y - MARKER_SIZE_HALF,
@@ -963,6 +946,7 @@ update_sat    (gpointer key, gpointer value, gpointer data)
                                                      2*MARKER_SIZE_HALF,
                                                      "fill-color-rgba", colour,
                                                      "stroke-color-rgba", colour,
+                                                     "tooltip", tooltip,
                                                      NULL);
             obj->label = goo_canvas_text_model_new (root, sat->nickname,
                                                     x,
@@ -971,7 +955,10 @@ update_sat    (gpointer key, gpointer value, gpointer data)
                                                     GTK_ANCHOR_NORTH,
                                                     "font", "Sans 8",
                                                     "fill-color-rgba", colour,
+                                                    "tooltip", tooltip,
                                                     NULL);
+
+            g_free (tooltip);
             
             goo_canvas_item_model_raise (obj->marker, NULL);
             goo_canvas_item_model_raise (obj->label, NULL);
@@ -1009,9 +996,21 @@ update_track (gpointer key, gpointer value, gpointer data)
 
 
     if (obj->showtrack) {
-
+          if (obj->pass == NULL) {
+               sat_log_log (SAT_LOG_LEVEL_BUG,
+                               _("%s:%d: Failed to get satellite pass."),
+                               __FILE__, __LINE__);
+               return;
+          }
+          
         /* create points */
         num = g_slist_length (obj->pass->details);
+        if (num == 0) {
+               sat_log_log (SAT_LOG_LEVEL_BUG,
+                               _("%s:%d: Pass had no points in it."),
+                               __FILE__, __LINE__);
+               return;
+          }
 
         points = goo_canvas_points_new (num);
 
@@ -1031,15 +1030,17 @@ update_track (gpointer key, gpointer value, gpointer data)
 
         for (i = 1; i < num-1; i++) {
             detail = PASS_DETAIL(g_slist_nth_data (obj->pass->details, i));
-            azel_to_xy (pv, detail->az, detail->el, &x, &y);
+            if (detail->el>=0)
+                azel_to_xy (pv, detail->az, detail->el, &x, &y);
             points->coords[2*i] = (double) x;
             points->coords[2*i+1] = (double) y;
 
             if (!(i % tres)) {
                 /* update time tick */
-                g_object_set (obj->trtick[ttidx],
-                              "x", (gdouble) x, "y", (gdouble) y,
-                              NULL);
+                if (ttidx<TRACK_TICK_NUM)
+                    g_object_set (obj->trtick[ttidx],
+                                  "x", (gdouble) x, "y", (gdouble) y,
+                                  NULL);
                 ttidx++;
             }
         }
@@ -1139,12 +1140,25 @@ static void create_track (GtkPolarView *pv, sat_obj_t *obj, sat_t *sat)
         return;
     }
 
+    if (obj->pass == NULL) {
+        sat_log_log (SAT_LOG_LEVEL_BUG,
+                     _("%s:%d: Failed to get satellite pass."),
+                     __FILE__, __LINE__);
+        return;
+    }
+
     root = goo_canvas_get_root_item_model (GOO_CANVAS (pv->canvas));
 
     /* add sky track */
 
     /* create points */
     num = g_slist_length (obj->pass->details);
+    if (num == 0) {
+        sat_log_log (SAT_LOG_LEVEL_BUG,
+                     _("%s:%d: Pass had no points in it."),
+                     __FILE__, __LINE__);
+        return;
+    }
 
     /* time resolution for time ticks; we need
                    3 additional points to AOS and LOS ticks.
@@ -1152,7 +1166,9 @@ static void create_track (GtkPolarView *pv, sat_obj_t *obj, sat_t *sat)
     tres = (num-2) / (TRACK_TICK_NUM-1);
 
     points = goo_canvas_points_new (num);
+    
 
+    
     /* first point should be (aos_az,0.0) */
     azel_to_xy (pv, obj->pass->aos_az, 0.0, &x, &y);
     points->coords[0] = (double) x;
@@ -1160,16 +1176,18 @@ static void create_track (GtkPolarView *pv, sat_obj_t *obj, sat_t *sat)
     obj->trtick[0] = create_time_tick (pv, obj->pass->aos, x, y);
 
     ttidx = 1;
-
+    
     for (i = 1; i < num-1; i++) {
         detail = PASS_DETAIL(g_slist_nth_data (obj->pass->details, i));
-        azel_to_xy (pv, detail->az, detail->el, &x, &y);
+        if (detail->el >= 0.0 )
+            azel_to_xy (pv, detail->az, detail->el, &x, &y);
         points->coords[2*i] = (double) x;
         points->coords[2*i+1] = (double) y;
 
         if (!(i % tres)) {
             /* create a time tick */
-            obj->trtick[ttidx] = create_time_tick (pv, detail->time, x, y);
+            if (ttidx<TRACK_TICK_NUM)
+                obj->trtick[ttidx] = create_time_tick (pv, detail->time, x, y);
             ttidx++;
         }
     }
@@ -1377,6 +1395,26 @@ on_button_press (GooCanvasItem *item,
 
     switch (event->button) {
 
+        /* double-left-click */
+    case 1:
+        if (event->type == GDK_2BUTTON_PRESS) {
+            catpoint = g_try_new0 (gint, 1);
+            *catpoint = catnum;
+
+            sat = SAT (g_hash_table_lookup (polv->sats, catpoint));
+            if (sat != NULL) {
+                show_sat_info(sat, gtk_widget_get_toplevel (GTK_WIDGET (data)));
+            }
+            else {
+                /* double-clicked on map */
+            }
+        }
+
+        g_free (catpoint);
+
+        break;
+
+
         /* pop-up menu */
     case 3:
         catpoint = g_try_new0 (gint, 1);
@@ -1412,8 +1450,8 @@ on_button_press (GooCanvasItem *item,
 /** \brief Manage button release events.
  *
  * This function is called when the mouse button is released above
- * a satellite object. It will act as a button click and if the relesed
- * button is the left one, the clock will correspond to selecting or
+ * a satellite object. It will act as a button click and if the released
+ * button is the left one, the click will correspond to selecting or
  * deselecting a satellite
  */
 static gboolean
@@ -1570,3 +1608,59 @@ gtk_polar_view_reload_sats (GtkWidget *polv, GHashTable *sats)
     GTK_POLAR_VIEW (polv)->naos = 0.0;
     GTK_POLAR_VIEW (polv)->ncat = 0;
 }
+
+
+
+/** \brief Convert LOS timestamp to human readable countdown string */
+static gchar *los_time_to_str (GtkPolarView *polv, sat_t *sat)
+{
+    guint    h,m,s;
+    gchar   *ch,*cm,*cs;
+    gdouble  number, now;
+    gchar   *text = NULL;
+
+
+    now = polv->tstamp;//get_current_daynum ();
+    number = sat->los - now;
+
+    /* convert julian date to seconds */
+    s = (guint) (number * 86400);
+
+    /* extract hours */
+    h = (guint) floor (s/3600);
+    s -= 3600*h;
+
+    /* leading zero */
+    if ((h > 0) && (h < 10))
+        ch = g_strdup ("0");
+    else
+        ch = g_strdup ("");
+
+    /* extract minutes */
+    m = (guint) floor (s/60);
+    s -= 60*m;
+
+    /* leading zero */
+    if (m < 10)
+        cm = g_strdup ("0");
+    else
+        cm = g_strdup ("");
+
+    /* leading zero */
+    if (s < 10)
+        cs = g_strdup (":0");
+    else
+        cs = g_strdup (":");
+
+    if (h > 0) {        
+        text = g_strdup_printf (_("LOS in %s%d:%s%d%s%d"), ch, h, cm, m, cs, s);
+    }
+    else {
+        text = g_strdup_printf (_("LOS in %s%d%s%d"), cm, m, cs, s);
+    }
+    g_free (ch);
+    g_free (cm);
+    g_free (cs);
+
+    return text;
+}
