@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2010  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -50,10 +50,14 @@
 
 /* NETWORK */
 //#include <sys/types.h>
+#ifndef WIN32
 #include <sys/socket.h>     /* socket(), connect(), send() */
 #include <netinet/in.h>     /* struct sockaddr_in */
 #include <arpa/inet.h>      /* htons() */
 #include <netdb.h>          /* gethostbyname() */
+#else
+#include <winsock2.h>
+#endif
 /* END */
 
 #define FMTSTR "%7.2f\302\260"
@@ -85,7 +89,16 @@ static void update_count_down (GtkRotCtrl *ctrl, gdouble t);
 static gboolean get_pos (GtkRotCtrl *ctrl, gdouble *az, gdouble *el);
 static gboolean set_pos (GtkRotCtrl *ctrl, gdouble az, gdouble el);
 
+static gboolean send_rotctld_command(GtkRotCtrl *ctrl, gchar *buff, gchar *buffout, gint sizeout);
+static gboolean open_rotctld_socket (GtkRotCtrl *ctrl);
+static gboolean close_rotctld_socket (gint *sock);
+
 static gboolean have_conf (void);
+static gint sat_name_compare (sat_t* a,sat_t*b);
+static gint rot_name_compare (const gchar* a,const gchar *b);
+
+static gboolean is_flipped_pass (pass_t * pass,rot_az_type_t type);
+static inline void set_flipped_pass (GtkRotCtrl* ctrl);
 
 static GtkVBoxClass *parent_class = NULL;
 
@@ -153,9 +166,10 @@ static void
     ctrl->pass = NULL;
     ctrl->qth = NULL;
     ctrl->plot = NULL;
-    
+    ctrl->sock = 0;
+
     ctrl->tracking = FALSE;
-    ctrl->busy = FALSE;
+    g_static_mutex_init(&(ctrl->busy));
     ctrl->engaged = FALSE;
     ctrl->delay = 1000;
     ctrl->timerid = 0;
@@ -180,6 +194,11 @@ static void
         g_free (ctrl->conf);
         ctrl->conf = NULL;
     }
+    
+    /*close the socket if it is still open*/
+    if (ctrl->sock!=0) {
+        close_rotctld_socket(&(ctrl->sock));
+    }
 
     (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -215,18 +234,19 @@ GtkWidget *
     GTK_ROT_CTRL (widget)->qth = module->qth;
     
     /* get next pass for target satellite */
-    if (GTK_ROT_CTRL (widget)->target->el > 0.0) {
-        GTK_ROT_CTRL (widget)->pass = get_current_pass (GTK_ROT_CTRL (widget)->target,
-                                                        GTK_ROT_CTRL (widget)->qth,
-                                                        0.0);
+    if (GTK_ROT_CTRL (widget)->target){
+        if (GTK_ROT_CTRL (widget)->target->el > 0.0) {
+            GTK_ROT_CTRL (widget)->pass = get_current_pass (GTK_ROT_CTRL (widget)->target,
+                                                            GTK_ROT_CTRL (widget)->qth,
+                                                            0.0);
+        }
+        else {
+            GTK_ROT_CTRL (widget)->pass = get_next_pass (GTK_ROT_CTRL (widget)->target,
+                                                         GTK_ROT_CTRL (widget)->qth,
+                                                         3.0);
+        }
     }
-    else {
-        GTK_ROT_CTRL (widget)->pass = get_next_pass (GTK_ROT_CTRL (widget)->target,
-                                                     GTK_ROT_CTRL (widget)->qth,
-                                                     3.0);
-    }
-
-
+    
     /* initialise custom colors */
     gdk_rgb_find_color (gtk_widget_get_colormap (widget), &ColBlack);
     gdk_rgb_find_color (gtk_widget_get_colormap (widget), &ColWhite);
@@ -284,15 +304,46 @@ void
         
         update_count_down (ctrl, t);
         
+        
         /* update next pass if necessary */
         if (ctrl->pass != NULL) {
-            if ((ctrl->target->aos > ctrl->pass->aos) && (ctrl->target->el <= 0.0)) {
-                /* we need to update the pass */
-                free_pass (ctrl->pass);
-                ctrl->pass = get_pass (ctrl->target, ctrl->qth, t, 3.0);
-                
-                /* update polar plot */
-                gtk_polar_plot_set_pass (GTK_POLAR_PLOT (ctrl->plot), ctrl->pass);
+            /*if we are not in the current pass*/
+            if ((ctrl->pass->aos>t)||(ctrl->pass->los<t)){
+                /* the pass may not have met the minimum 
+                   elevation, calculate the pass and plot it*/
+                if (ctrl->target->el >= 0.0) {
+                    /*inside an unexpected/unpredicted pass*/
+                    free_pass (ctrl->pass);
+                    ctrl->pass=NULL;
+                    ctrl->pass = get_current_pass (ctrl->target, ctrl->qth, t);
+                    set_flipped_pass(ctrl);
+                    gtk_polar_plot_set_pass (GTK_POLAR_PLOT (ctrl->plot), ctrl->pass);
+                } else if ((ctrl->target->aos-ctrl->pass->aos)>(ctrl->delay/secday/1000/4.0)) {
+                    /*the target is expected to appear in a new pass 
+                      sufficiently later after the current pass says*/
+                    
+                    /*converted milliseconds to gpredict time and took a 
+                      fraction of it as a threshold for deciding a new pass*/
+                    
+                    /*if the next pass is not the one for the target*/
+                    free_pass (ctrl->pass);
+                    ctrl->pass=NULL;
+                    ctrl->pass = get_pass (ctrl->target, ctrl->qth, t, 3.0);
+                    set_flipped_pass(ctrl);
+                    /* update polar plot */
+                    gtk_polar_plot_set_pass (GTK_POLAR_PLOT (ctrl->plot), ctrl->pass);
+                }
+            } else {
+                /* inside a pass and target dropped below the 
+                   horizon so look for a new pass */
+                if (ctrl->target->el < 0.0) {
+                    free_pass (ctrl->pass);
+                    ctrl->pass=NULL;
+                    ctrl->pass = get_pass (ctrl->target, ctrl->qth, t, 3.0);
+                    set_flipped_pass(ctrl);
+                    /* update polar plot */
+                    gtk_polar_plot_set_pass (GTK_POLAR_PLOT (ctrl->plot), ctrl->pass);
+                }
             }
         }
         else {
@@ -303,7 +354,7 @@ void
             else {
                 ctrl->pass = get_pass (ctrl->target, ctrl->qth, t, 3.0);
             }
-            
+            set_flipped_pass(ctrl);
             /* update polar plot */
             gtk_polar_plot_set_pass (GTK_POLAR_PLOT (ctrl->plot), ctrl->pass);
         }
@@ -472,7 +523,7 @@ static GtkWidget *
     gchar       *dirname;      /* directory name */
     gchar      **vbuff;
     const gchar *filename;     /* file name */
-
+    gchar       *rotname;
     
     
     table = gtk_table_new (3, 3, FALSE);
@@ -494,15 +545,27 @@ static GtkWidget *
     dir = g_dir_open (dirname, 0, &error);
     if (dir) {
         /* read each .rot file */
+        GSList *rots=NULL;
+        gint i;
+        gint n;
         while ((filename = g_dir_read_name (dir))) {
             
-            if (g_strrstr (filename, ".rot")) {
+            if (g_str_has_suffix (filename, ".rot")) {
                 
                 vbuff = g_strsplit (filename, ".rot", 0);
-                gtk_combo_box_append_text (GTK_COMBO_BOX (ctrl->DevSel), vbuff[0]);
+                rots=g_slist_insert_sorted(rots,g_strdup(vbuff[0]),(GCompareFunc)rot_name_compare);
                 g_strfreev (vbuff);
             }
         }
+        n = g_slist_length (rots);
+        for (i = 0; i < n; i++) {
+            rotname = g_slist_nth_data (rots, i);
+            if (rotname) {
+                gtk_combo_box_append_text (GTK_COMBO_BOX (ctrl->DevSel), rotname);
+                g_free(rotname);
+            }
+        }
+        g_slist_free(rots);
     }
     else {
         sat_log_log (SAT_LOG_LEVEL_ERROR,
@@ -600,7 +663,8 @@ static void
     GtkRotCtrl *ctrl = GTK_ROT_CTRL( user_data);
     sat_t        *sat = SAT (value);
 
-    ctrl->sats = g_slist_append (ctrl->sats, sat);
+    //ctrl->sats = g_slist_append (ctrl->sats, sat);
+    ctrl->sats = g_slist_insert_sorted (ctrl->sats, sat, (GCompareFunc)sat_name_compare);
 }
 
 
@@ -628,6 +692,9 @@ static void
             ctrl->pass = get_current_pass (ctrl->target, ctrl->qth, ctrl->t);
         else
             ctrl->pass = get_pass (ctrl->target, ctrl->qth, ctrl->t, 3.0);
+
+        set_flipped_pass(ctrl);
+
     }
     else {
         sat_log_log (SAT_LOG_LEVEL_ERROR,
@@ -737,6 +804,9 @@ static void
         /* update new ranges of the Az and El controller widgets */
         gtk_rot_knob_set_range (GTK_ROT_KNOB (ctrl->AzSet), ctrl->conf->minaz, ctrl->conf->maxaz);
         gtk_rot_knob_set_range (GTK_ROT_KNOB (ctrl->ElSet), ctrl->conf->minel, ctrl->conf->maxel);
+
+        /*Update flipped when changing rotor if there is a plot*/
+        set_flipped_pass(ctrl);
     }
     else {
         sat_log_log (SAT_LOG_LEVEL_ERROR,
@@ -752,6 +822,7 @@ static void
 }
 
 
+
 /** \brief Rotor locked.
  * \param button Pointer to the "Engage" button.
  * \param data Pointer to the GtkRotCtrl widget.
@@ -766,6 +837,7 @@ static void
     if (!gtk_toggle_button_get_active (button)) {
         gtk_widget_set_sensitive (ctrl->DevSel, TRUE);
         ctrl->engaged = FALSE;
+        close_rotctld_socket(&(ctrl->sock));
         gtk_label_set_text (GTK_LABEL (ctrl->AzRead), "---");
         gtk_label_set_text (GTK_LABEL (ctrl->ElRead), "---");
     }
@@ -779,7 +851,7 @@ static void
         }
         gtk_widget_set_sensitive (ctrl->DevSel, FALSE);
         ctrl->engaged = TRUE;
-        
+        open_rotctld_socket(ctrl);
         ctrl->wrops = 0;
         ctrl->rdops = 0;
     }
@@ -795,49 +867,57 @@ static gboolean
 {
     GtkRotCtrl *ctrl = GTK_ROT_CTRL (data);
     gdouble rotaz=0.0, rotel=0.0;
-    gdouble setaz,setel;
+    gdouble setaz=0.0, setel=45.0;
     gchar *text;
     gboolean error = FALSE;
+    sat_t sat_working, *sat;
+    /*parameters for path predictions*/
+    gdouble time_delta;
+    gdouble step_size;
     
     
-    if (ctrl->busy) {
+    if (g_static_mutex_trylock(&(ctrl->busy))==FALSE) {
         sat_log_log (SAT_LOG_LEVEL_ERROR,_("%s missed the deadline"),__FUNCTION__);
         return TRUE;
     }
     
-    ctrl->busy = TRUE;
-    
     /* If we are tracking and the target satellite is within
        range, set the rotor position controller knob values to
        the target values. If the target satellite is out of range
        set the rotor controller to 0 deg El and to the Az where the
-       target sat is expected to come up
+       target sat is expected to come up or where it last went down
     */
-    if (ctrl->tracking) {
+    if (ctrl->tracking && ctrl->target) {
         if (ctrl->target->el < 0.0) {
-            gdouble aosaz = 0.0;
-            
             if (ctrl->pass != NULL) {
-                aosaz = ctrl->pass->aos_az;
-                
-                if ((ctrl->conf->aztype == ROT_AZ_TYPE_180) && (aosaz > 180.0)) {
-                    aosaz -= 360.0;
+                if (ctrl->t < ctrl->pass->aos) {
+                    setaz=ctrl->pass->aos_az;
+                    setel=0;
+                } else if (ctrl->t > ctrl->pass->los) {
+                    setaz=ctrl->pass->los_az;
+                    setel=0;
                 }
             }
-            gtk_rot_knob_set_value (GTK_ROT_KNOB (ctrl->AzSet), aosaz);
-            gtk_rot_knob_set_value (GTK_ROT_KNOB (ctrl->ElSet), 0.0);
         }
-        else {
-            if ((ctrl->conf->aztype == ROT_AZ_TYPE_180) &&
-                (ctrl->target->az > 180.0)) {
-                gtk_rot_knob_set_value (GTK_ROT_KNOB (ctrl->AzSet), ctrl->target->az - 360.0);
-            }
-            else {
-                gtk_rot_knob_set_value (GTK_ROT_KNOB (ctrl->AzSet), ctrl->target->az);
-            }
-            gtk_rot_knob_set_value (GTK_ROT_KNOB (ctrl->ElSet), ctrl->target->el);
+        else { 
+            setaz=ctrl->target->az;
+            setel=ctrl->target->el;
         }
-        
+        /* if this is a flipped pass and the rotor supports it*/
+        if ((ctrl->flipped)&&(ctrl->conf->maxel>=180.0)){
+            setel=180-setel;
+            if (setaz>180)
+                setaz-=180;
+            else
+                setaz+=180;
+        }
+        if ((ctrl->conf->aztype == ROT_AZ_TYPE_180) && (setaz > 180.0)) {
+            setaz = setaz- 360.0;
+        }
+
+    } else {
+        setaz = gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->AzSet));
+        setel = gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->ElSet));
     }
 
     if ((ctrl->engaged) && (ctrl->conf != NULL)) {
@@ -869,13 +949,88 @@ static gboolean
         }
         
         /* if tolerance exceeded */
-        setaz = gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->AzSet));
-        setel = gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->ElSet));
         if ((fabs(setaz-rotaz) > ctrl->tolerance) ||
             (fabs(setel-rotel) > ctrl->tolerance)) {
+            
+            if (ctrl->tracking){
+                /*if we are in a pass try to lead the satellite 
+                  some so we are not always chasing it*/
+                if (ctrl->target->el>0.0) {
+                    /*starting the rotator moving while we do some computation can lead to errors later*/
+                    /* 
+                       compute a time in the future when the position is 
+                       within tolerance so and send the rotor there.
+                    */         
+                    
+                    /*use a working copy so data does not get corrupted*/
+                    sat=memcpy(&(sat_working),ctrl->target,sizeof(sat_t));
+                    
+                    /*
+                      compute az/el in the future that is past end of pass 
+                      or exceeds tolerance
+                    */
+                    if (ctrl->pass) {
+                        /* the next point is before the end of the pass 
+                           if there is one.*/
+                        time_delta=ctrl->pass->los-ctrl->t;
+                    } else {
+                        /* otherwise look 20 minutes into the future*/
+                        time_delta=1.0/72.0;
+                    }
+                    /* have a minimum time delta*/
+                    if (time_delta<(ctrl->delay/1000.0/secday)){
+                        time_delta=ctrl->delay/1000.0/secday;
+                    }
+
+
+                    step_size = time_delta / 2.0;
+                    
+                    /*
+                      find a time when satellite is above horizon and at the 
+                      edge of tolerance. the final step size needs to be smaller
+                      than delay. otherwise the az/el could be further away than
+                      tolerance the next time we enter the loop and we end up 
+                      pushing ourselves away from the satellite.
+                    */
+                    while (step_size > (ctrl->delay/1000.0/4.0/(secday))) {
+                        predict_calc (sat,ctrl->qth,ctrl->t+time_delta);
+                        /*update sat->az and sat->el to account for flips and az range*/
+                        if ((ctrl->flipped) && (ctrl->conf->maxel >= 180.0)){
+                            sat->el = 180.0-sat->el;
+                            if (sat->az > 180.0)
+                                sat->az -= 180.0;
+                            else
+                                sat->az += 180.0;
+                        }
+                        if ((ctrl->conf->aztype == ROT_AZ_TYPE_180) && (sat->az > 180.0)) { 
+                            sat->az = sat->az - 360.0;
+                        } 
+                        if ((sat->el < 0.0)||(sat->el > 180.0)||
+                            (fabs(setaz - sat->az) > (ctrl->tolerance)) ||
+                            (fabs(setel - sat->el) > (ctrl->tolerance))) {
+                            time_delta -= step_size;
+                        } else {
+                            time_delta += step_size;
+                        }
+                        step_size /= 2.0;
+                    }
+                    setel = sat->el;
+                    if (setel < 0.0) {
+                        setel = 0.0;
+                    }
+                    if (setel > 180.0) {
+                        setel = 180.0;
+                    }
+                    setaz = sat->az;
+                }
+            }
             /* send controller values to rotator device */
+            /* this is the newly computed value which should be ahead of the current position */
             if (!set_pos (ctrl, setaz, setel)) {
                 error = TRUE;
+            } else {
+                gtk_rot_knob_set_value (GTK_ROT_KNOB (ctrl->AzSet), setaz);
+                gtk_rot_knob_set_value (GTK_ROT_KNOB (ctrl->ElSet), setel);
             }
         }
         
@@ -913,19 +1068,20 @@ static gboolean
     }
     
     /* update controller circle on polar plot */
-    if ((ctrl->conf->aztype == ROT_AZ_TYPE_180) && (rotaz < 0.0)) {
-        gtk_polar_plot_set_ctrl_pos (GTK_POLAR_PLOT (ctrl->plot),
-                                     gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->AzSet))+360.0,
-                                     gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->ElSet)));
+    if (ctrl->conf !=NULL){
+        if ((ctrl->conf->aztype == ROT_AZ_TYPE_180) && (setaz < 0.0)) {
+            gtk_polar_plot_set_ctrl_pos (GTK_POLAR_PLOT (ctrl->plot),
+                                         gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->AzSet))+360.0,
+                                         gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->ElSet)));
+        }
+        else {
+            gtk_polar_plot_set_ctrl_pos (GTK_POLAR_PLOT (ctrl->plot),
+                                         gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->AzSet)),
+                                         gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->ElSet)));
+        }
     }
-    else {
-        gtk_polar_plot_set_ctrl_pos (GTK_POLAR_PLOT (ctrl->plot),
-                                     gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->AzSet)),
-                                     gtk_rot_knob_get_value (GTK_ROT_KNOB (ctrl->ElSet)));
-    }
-    
-    ctrl->busy = FALSE;
-    
+    g_static_mutex_unlock(&(ctrl->busy));
+
     return TRUE;
 }
 
@@ -940,13 +1096,9 @@ static gboolean
 static gboolean get_pos (GtkRotCtrl *ctrl, gdouble *az, gdouble *el)
 {
     gchar  *buff,**vbuff;
-    gint    written,size;
-    gint    status;
-    struct hostent *h;
-    struct sockaddr_in ServAddr;
-    gint  sock;          /*!< Network socket */
-
-
+    gchar  buffback[128];
+    gboolean retcode;
+    
     if ((az == NULL) || (el == NULL)) {
         sat_log_log (SAT_LOG_LEVEL_BUG,
                      _("%s:%d: NULL storage."),
@@ -954,96 +1106,45 @@ static gboolean get_pos (GtkRotCtrl *ctrl, gdouble *az, gdouble *el)
         return FALSE;
     }
     
-    /* create socket */
-    sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP);
-    if (sock < 0) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%d: Failed to create socket"),
-                     __FILE__, __LINE__);
-        return FALSE;
-    }
-    else {
-        sat_log_log (SAT_LOG_LEVEL_DEBUG,
-                     _("%s:%d Network socket created successfully"),
-                     __FILE__, __LINE__);
-    }
-
-    memset(&ServAddr, 0, sizeof(ServAddr));     /* Zero out structure */
-    ServAddr.sin_family = AF_INET;             /* Internet address family */
-    h = gethostbyname(ctrl->conf->host);
-    memcpy((char *) &ServAddr.sin_addr.s_addr, h->h_addr_list[0], h->h_length);
-    ServAddr.sin_port = htons(ctrl->conf->port); /* Server port */
-
-    /* establish connection */
-    status = connect(sock, (struct sockaddr *) &ServAddr, sizeof(ServAddr));
-    if (status < 0) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%d: Failed to connect to %s:%d"),
-                     __FILE__, __LINE__, ctrl->conf->host, ctrl->conf->port);
-        return FALSE;
-    }
-    else {
-        sat_log_log (SAT_LOG_LEVEL_DEBUG,
-                     _("%s:%d: Connection opened to %s:%d"),
-                     __FILE__, __LINE__, ctrl->conf->host, ctrl->conf->port);
-    }
-    
     /* send command */
-    buff = g_strdup_printf ("p");
-    
-    size = 1;
-    written = send(sock, buff, size, 0);
-    if (written != size) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%d: SIZE ERROR %d / %d"),
-                     __FILE__, __LINE__, written, size);
-    }
-    g_free (buff);
-    
+    buff = g_strdup_printf ("p\x0a");
+
+    retcode=send_rotctld_command(ctrl,buff,buffback,128);
     
     /* try to read answer */
-    buff = g_try_malloc (128);
-    if (buff == NULL) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%s: Failed to allocate 128 bytes (yes, this means trouble)"),
-                     __FILE__, __FUNCTION__);
-        shutdown (sock, SHUT_RDWR);
-        close (sock);
-        return FALSE;
+    if (retcode) {
+        if (strncmp(buffback,"RPRT",4)==0){
+            //retcode=FALSE;
+            g_strstrip (buffback);
+            sat_log_log (SAT_LOG_LEVEL_ERROR,
+                         _("%s:%d: rotctld returned error (%s)"),
+                         __FILE__, __LINE__,buffback);
+
+        } else {
+            vbuff = g_strsplit (buffback, "\n", 3);
+            if ((vbuff[0] !=NULL) && (vbuff[1]!=NULL)){
+                *az = g_strtod (vbuff[0], NULL);
+                *el = g_strtod (vbuff[1], NULL);
+            } else {
+                g_strstrip (buffback);
+                sat_log_log (SAT_LOG_LEVEL_ERROR,
+                             _("%s:%d: rotctld returned bad response (%s)"),
+                             __FILE__, __LINE__,buffback);
+                //retcode=FALSE;
+            }
+            
+            g_strfreev (vbuff);
+        }
     }
 
-    size = read (sock, buff, 127);
-    if (size == 0) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%s: Got 0 bytes from rotctld"),
-                     __FILE__, __FUNCTION__);
-    }
-    else {
-        sat_log_log (SAT_LOG_LEVEL_DEBUG,
-                     _("%s:%s: Read %d bytes from rotctld"),
-                     __FILE__, __FUNCTION__, size);
-        
-        buff[size] = 0;
-        vbuff = g_strsplit (buff, "\n", 3);
-        *az = g_strtod (vbuff[0], NULL);
-        *el = g_strtod (vbuff[1], NULL);
+    g_free (buff);
 
-        g_free (buff);
-        g_strfreev (vbuff);
-    }
-    
-    shutdown (sock, SHUT_RDWR);
-    close (sock);
-
-    ctrl->wrops++;
-    ctrl->rdops++;
-    
-    return TRUE;
+    return retcode;
 }
 
 
 /** \brief Send new position to rotator device
- * \param ctrl Poitner to the GtkRotCtrl widget
+ * \param ctrl Pointer to the GtkRotCtrl widget
  * \param az The new Azimuth
  * \param el The new Elevation
  * \return TRUE if the new position has been sent successfully
@@ -1055,71 +1156,44 @@ static gboolean get_pos (GtkRotCtrl *ctrl, gdouble *az, gdouble *el)
 static gboolean set_pos (GtkRotCtrl *ctrl, gdouble az, gdouble el)
 {
     gchar  *buff;
+    gchar  buffback[128];
     gchar  azstr[8],elstr[8];
-    gint    written,size;
-    gint    status;
-    struct hostent *h;
-    struct sockaddr_in ServAddr;
-    gint  sock;          /*!< Network socket */
-
-    
-    /* create socket */
-    sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP);
-    if (sock < 0) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%d: Failed to create socket"),
-                     __FILE__, __LINE__);
-        return FALSE;
-    }
-    else {
-        sat_log_log (SAT_LOG_LEVEL_DEBUG,
-                     _("%s:%d Network socket created successfully"),
-                     __FILE__, __LINE__);
-    }
-
-    memset(&ServAddr, 0, sizeof(ServAddr));     /* Zero out structure */
-    ServAddr.sin_family = AF_INET;             /* Internet address family */
-    h = gethostbyname(ctrl->conf->host);
-    memcpy((char *) &ServAddr.sin_addr.s_addr, h->h_addr_list[0], h->h_length);
-    ServAddr.sin_port = htons(ctrl->conf->port); /* Server port */
-
-    /* establish connection */
-    status = connect(sock, (struct sockaddr *) &ServAddr, sizeof(ServAddr));
-    if (status < 0) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%d: Failed to connect to %s:%d"),
-                     __FILE__, __LINE__, ctrl->conf->host, ctrl->conf->port);
-        return FALSE;
-    }
-    else {
-        sat_log_log (SAT_LOG_LEVEL_DEBUG,
-                     _("%s:%d: Connection opened to %s:%d"),
-                     __FILE__, __LINE__, ctrl->conf->host, ctrl->conf->port);
-    }
+    gboolean retcode;
+    gint   retval;
     
     /* send command */
     g_ascii_formatd (azstr, 8, "%7.2f", az);
     g_ascii_formatd (elstr, 8, "%7.2f", el);
-    buff = g_strdup_printf ("P %s %s", azstr, elstr);
+    buff = g_strdup_printf ("P %s %s\x0a", azstr, elstr);
     
-    size = 17;
-    written = send(sock, buff, size, 0);
-    if (written != size) {
-        sat_log_log (SAT_LOG_LEVEL_ERROR,
-                     _("%s:%d: SIZE ERROR %d / %d"),
-                     __FILE__, __LINE__, written, size);
-    }
-    
-    //g_print ("SZ:%d  WR:%d  AZ:%s  EL:%s  STR:%s", size, written, azstr, elstr, buff);
+    retcode=send_rotctld_command(ctrl,buff,buffback,128);
     
     g_free (buff);
     
-    shutdown (sock, SHUT_RDWR);
-    close (sock);
-    
-    ctrl->wrops++;
+    if (retcode==TRUE){
+        retval=(gint)g_strtod(buffback+4,NULL);
+        /*treat errors as soft errors unless there is good reason*/
+        /*good reasons come from operator experience or documentation*/
+        switch(retval) {
+            
+        case 0:
+            /*no error case*/
+            break;
+        default:
+            /*any other case*/
+            /*not sure what is a hard error or soft error*/
+            /*over time a database of this is needed*/
+            g_strstrip (buffback);
+            sat_log_log (SAT_LOG_LEVEL_ERROR,
+                         _("%s:%d: rotctld returned error %d with az %f el %f(%s)"),
+                         __FILE__, __LINE__, retval, az, el, buffback);
+            
+            //retcode=FALSE;
+            break;
+        }
+    }
 
-    return TRUE;
+    return (retcode);
 }
 
 
@@ -1211,8 +1285,10 @@ static gboolean have_conf ()
         /* read each .rot file */
         while ((filename = g_dir_read_name (dir))) {
             
-            if (g_strrstr (filename, ".rot")) {
+            if (g_str_has_suffix (filename, ".rot")) {
                 i++;
+                /*once we have one we need nothing else*/
+                break;
             }
         }
     }
@@ -1228,3 +1304,208 @@ static gboolean have_conf ()
     
     return (i > 0) ? TRUE : FALSE;
 }
+
+/** \brief open the rotcld socket. return true if successful false otherwise.*/
+
+static gboolean open_rotctld_socket (GtkRotCtrl * ctrl) {
+    struct sockaddr_in ServAddr;
+    struct hostent *h;
+    gint status;
+
+    ctrl->sock=socket(PF_INET,SOCK_STREAM,IPPROTO_TCP);
+    if (ctrl->sock < 0) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: Failed to create socket"),
+                     __FUNCTION__);
+        ctrl->sock = 0;
+        return FALSE;
+    }
+    else {
+        sat_log_log (SAT_LOG_LEVEL_DEBUG,
+                     _("%s: Network socket created successfully"),
+                     __FUNCTION__);
+    }
+
+    memset(&ServAddr, 0, sizeof(ServAddr));     /* Zero out structure */
+    ServAddr.sin_family = AF_INET;             /* Internet address family */
+    h = gethostbyname(ctrl->conf->host);
+    memcpy((char *) &ServAddr.sin_addr.s_addr, h->h_addr_list[0], h->h_length);
+    ServAddr.sin_port = htons(ctrl->conf->port); /* Server port */
+
+    /* establish connection */
+    status = connect(ctrl->sock, (struct sockaddr *) &ServAddr, sizeof(ServAddr));
+    if (status < 0) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: Failed to connect to %s:%d"),
+                     __FUNCTION__, ctrl->conf->host, ctrl->conf->port);
+        ctrl->sock = 0;
+        return FALSE;
+    }
+    else {
+        sat_log_log (SAT_LOG_LEVEL_DEBUG,
+                     _("%s: Connection opened to %s:%d"),
+                     __FUNCTION__, ctrl->conf->host, ctrl->conf->port);
+    }
+
+    return TRUE;
+}
+
+
+/*close a rotcld socket. First send a q command to cleanly shut down rotctld*/
+static gboolean close_rotctld_socket (gint *sock) {
+  gint written;
+  /*shutdown the rigctld connect*/
+  written = send(*sock, "q\x0a", 2, 0);
+  
+#ifndef WIN32
+  shutdown (*sock, SHUT_RDWR);
+#else
+  shutdown (*sock, SD_BOTH);
+#endif
+  
+  close (*sock);
+
+  *sock=0;
+  
+  return TRUE;
+}
+
+/** \brief  Send a command to rigctld
+ *   Inputs are a controller, a string command, and a buffer and length for returning the output from rigctld.
+ */
+
+gboolean send_rotctld_command(GtkRotCtrl *ctrl, gchar *buff, gchar *buffout, gint sizeout)
+{
+    gint    written;
+    gint    size;
+
+    size = strlen(buff);
+    
+    //sat_log_log (SAT_LOG_LEVEL_DEBUG,
+    //             _("%s:%s: Sending %d bytes as %s."),
+    //             __FILE__, __FUNCTION__, size, buff);
+
+
+    /* send command */
+    written = send(ctrl->sock, buff, size, 0);
+    if (written != size) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: SIZE ERROR %d / %d"),
+                     __FUNCTION__, written, size);
+    }
+    if (written == -1) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: rotctld Socket Down"),
+                     __FUNCTION__);
+        return FALSE;
+    }
+
+    /* try to read answer */
+    size = read (ctrl->sock, buffout, sizeout);
+
+    if (size == -1) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: rotctld Socket Down"),
+                     __FUNCTION__);
+        return FALSE;
+    }  
+
+    buffout[size]='\0';
+    if (size == 0) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s:%s: Got 0 bytes from rotctld"),
+                     __FILE__, __FUNCTION__);
+    }
+    else {
+        //sat_log_log (SAT_LOG_LEVEL_DEBUG,
+        //             _("%s:%s: Read %d bytes as %s from rotctld"),
+        //             __FILE__, __FUNCTION__, size, buffout);
+        
+    }
+
+    ctrl->wrops++;
+    
+    return TRUE;
+}
+
+/** \brief  Compare Satellite Names.
+ *simple function to sort the list of satellites in the combo box.
+ */
+static gint sat_name_compare (sat_t* a,sat_t*b){
+    return (g_ascii_strcasecmp(a->nickname,b->nickname));
+}
+
+
+/** \brief  Compare Rotator Names.
+ */
+static gint rot_name_compare (const gchar* a,const gchar *b){
+    return (g_ascii_strcasecmp(a,b));
+}
+
+
+/** \brief  Compute if a pass is flipped or not.  this is a function of the rotator and the particular pass. 
+ */
+static gboolean is_flipped_pass (pass_t * pass,rot_az_type_t type){
+    gdouble max_az,min_az;
+    gdouble caz,last_az=pass->aos_az;
+    guint num,i;
+    pass_detail_t      *detail;
+    gboolean retval=FALSE;
+
+    num = g_slist_length (pass->details);
+    if (type==ROT_AZ_TYPE_360) {
+        min_az = 0;
+        max_az = 360;
+    } 
+    else if (type==ROT_AZ_TYPE_180) {
+        min_az = -180;
+        max_az = 180;
+    }
+    
+    /* Assume that min_az and max_az are atleat 360 degrees apart*/
+    /*get the azimuth that is in a settable range*/
+    while (last_az>max_az) {
+        last_az-=360;
+    } 
+    while (last_az<min_az) {
+        last_az+=360;
+    }
+    
+    if (num>1) {
+        for (i = 1; i < num-1; i++) {
+            detail = PASS_DETAIL(g_slist_nth_data (pass->details, i));
+            caz=detail->az;
+            while (caz>max_az) {
+                caz-=360;
+            } 
+            while (caz<min_az) {
+                caz+=360;
+            }
+            if (fabs(caz-last_az)>180) {
+                retval=TRUE;
+            }
+            last_az=caz;
+            
+        }
+    }
+    caz=pass->los_az;
+    while (caz>max_az) {
+        caz-=360;
+    } 
+    while (caz<min_az) {
+        caz+=360;
+    }
+    if (fabs(caz-last_az)>180) {
+        retval=TRUE;
+    }
+    
+    return retval;
+}
+
+static inline void set_flipped_pass (GtkRotCtrl* ctrl){
+    if (ctrl->conf)
+        if (ctrl->pass){
+            ctrl->flipped=is_flipped_pass(ctrl->pass,ctrl->conf->aztype);
+        }
+
+}
