@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -36,5 +36,5 @@
 gint gtk_sat_data_read_sat (gint catnum, sat_t *sat);
 void gtk_sat_data_init_sat (sat_t *sat, qth_t *qth);
 void gtk_sat_data_copy_sat (const sat_t *source, sat_t *dest, qth_t *qth);
-
+void gtk_sat_data_free_sat (sat_t *sat);
 #endif
