@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -53,6 +53,7 @@
 #include "gtk-sat-map.h"
 #include "locator.h"
 #include "sat-debugger.h"
+#include "sat-info.h"
 #ifdef HAVE_CONFIG_H
 #  include <build-config.h>
 #endif
@@ -101,6 +102,7 @@ static gint compare_coordinates_y  (gconstpointer a, gconstpointer b, gpointer d
 static void update_selected        (GtkSatMap *satmap, sat_t *sat);
 static void draw_grid_lines        (GtkSatMap *satmap, GooCanvasItemModel *root);
 static void redraw_grid_lines      (GtkSatMap *satmap);
+static gchar *aoslos_time_to_str   (GtkSatMap *satmap, sat_t *sat);
 
 static GtkVBoxClass *parent_class = NULL;
 static GooCanvasPoints *points1;
@@ -251,6 +253,7 @@ gtk_sat_map_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 
     /* create the canvas */
     GTK_SAT_MAP (satmap)->canvas = goo_canvas_new ();
+    g_object_set (G_OBJECT (GTK_SAT_MAP (satmap)->canvas), "has-tooltip", TRUE, NULL);
 
     /* safely load a background map */
     load_map_file (GTK_SAT_MAP (satmap));
@@ -313,8 +316,8 @@ create_canvas_model (GtkSatMap *satmap)
     root = goo_canvas_group_model_new (NULL, NULL);
 
     /* map dimensions */
-    satmap->width = gdk_pixbuf_get_width (satmap->origmap);
-    satmap->height = gdk_pixbuf_get_height (satmap->origmap);
+    satmap->width = 200; // was: gdk_pixbuf_get_width (satmap->origmap);
+    satmap->height = 100; // was: gdk_pixbuf_get_height (satmap->origmap);
     satmap->x0 = 0;
     satmap->y0 = 0;
 
@@ -720,16 +723,12 @@ gtk_sat_map_update (GtkWidget  *widget)
  *  \param x The X coordinate on the screen (left to right)
  *  \param y The Y coordinate on the screen (top to bottom)
  *
+ * Assumes that -180 <= lon <= 180 and -90 <= lat <= 90
  */
 static void
 lonlat_to_xy (GtkSatMap *p, gdouble lon, gdouble lat, gfloat *x, gfloat *y)
 {
-    *x = p->x0 + (180.0 - lon) * p->width / 360.0;
-    if (*x < 0.0) /* west longitude */
-        *x *= -1;
-    else  /* east longitude */
-        *x = p->x0 + (180.0 + lon) * p->width / 360.0;
-
+    *x = p->x0 + (180.0 + lon) * p->width / 360.0;
     *y = p->y0 + (90.0 - lat) * p->height / 180.0;;
 }
 
@@ -844,6 +843,26 @@ on_button_press (GooCanvasItem *item,
 
     switch (event->button) {
 
+        /* double-left-click */
+    case 1:
+        if (event->type == GDK_2BUTTON_PRESS) {
+            catpoint = g_try_new0 (gint, 1);
+            *catpoint = catnum;
+
+            sat = SAT (g_hash_table_lookup (satmap->sats, catpoint));
+            if (sat != NULL) {
+                show_sat_info(sat, gtk_widget_get_toplevel (GTK_WIDGET (data)));
+            }
+            else {
+                /* double-clicked on map */
+            }
+        }
+
+        g_free (catpoint);
+
+        break;
+
+
         /* pop-up menu */
     case 3:
         catpoint = g_try_new0 (gint, 1);
@@ -874,8 +893,8 @@ on_button_press (GooCanvasItem *item,
 /** \brief Manage button release events.
  *
  * This function is called when the mouse button is released above
- * a satellite object. It will act as a button click and if the relesed
- * button is the left one, the clock will correspond to selecting or
+ * a satellite object. It will act as a button click and if the released
+ * button is the left one, the click will correspond to selecting or
  * deselecting a satellite
  */
 static gboolean
@@ -1633,8 +1652,9 @@ plot_sat (gpointer key, gpointer value, gpointer data)
     sat_t *sat = SAT(value);
     GooCanvasItemModel *root;
     gint *catnum;
-    guint32 col,covcol;
+    guint32 col,covcol,shadowcol;
     gfloat x,y;
+    gchar *tooltip;
 
     /* get satellite and SSP */
     catnum = g_new0 (gint, 1);
@@ -1664,16 +1684,37 @@ plot_sat (gpointer key, gpointer value, gpointer data)
                            SAT_CFG_INT_MAP_SAT_COL);
 
     /* area coverage colour */
-    /*     if ((obj->showcov) && (sat->otype != ORBIT_TYPE_DECAYED)) { */
     covcol = mod_cfg_get_int (satmap->cfgdata,
                               MOD_CFG_MAP_SECTION,
                               MOD_CFG_MAP_SAT_COV_COL,
                               SAT_CFG_INT_MAP_SAT_COV_COL);
-    /*     } */
-    /*     else { */
-    /*         covcol = 0x00000000; */
-    /*     } */
 
+    /* shadow colour (only alpha channel) */
+    shadowcol = mod_cfg_get_int (satmap->cfgdata,
+                                 MOD_CFG_MAP_SECTION,
+                                 MOD_CFG_MAP_SHADOW_ALPHA,
+                                 SAT_CFG_INT_MAP_SHADOW_ALPHA);
+
+    /* create tooltip */
+    tooltip = g_strdup_printf("<big><b>%s</b>\n</big>"\
+                              "<tt>Lon: %5.1f\302\260\n" \
+                              "Lat: %5.1f\302\260\n" \
+                              " Az: %5.1f\302\260\n" \
+                              " El: %5.1f\302\260</tt>",
+                              sat->nickname,
+                              sat->ssplon, sat->ssplat,
+                              sat->az, sat->el);
+
+
+    /* create satellite marker and label + shadows. We create shadows first */
+    obj->shadowm = goo_canvas_rect_model_new (root,
+                                              x - MARKER_SIZE_HALF + 1,
+                                              y - MARKER_SIZE_HALF + 1,
+                                              2 * MARKER_SIZE_HALF,
+                                              2 * MARKER_SIZE_HALF,
+                                              "fill-color-rgba", 0x00,
+                                              "stroke-color-rgba", shadowcol,
+                                              NULL);
     obj->marker = goo_canvas_rect_model_new (root,
                                              x - MARKER_SIZE_HALF,
                                              y - MARKER_SIZE_HALF,
@@ -1681,8 +1722,17 @@ plot_sat (gpointer key, gpointer value, gpointer data)
                                              2 * MARKER_SIZE_HALF,
                                              "fill-color-rgba", col,
                                              "stroke-color-rgba", col,
+                                             "tooltip", tooltip,
                                              NULL);
 
+    obj->shadowl = goo_canvas_text_model_new (root, sat->nickname,
+                                            x+1,
+                                            y+3,
+                                            -1,
+                                            GTK_ANCHOR_NORTH,
+                                            "font", "Sans 8",
+                                            "fill-color-rgba", shadowcol,
+                                            NULL);
     obj->label = goo_canvas_text_model_new (root, sat->nickname,
                                             x, 
                                             y+2,
@@ -1690,8 +1740,11 @@ plot_sat (gpointer key, gpointer value, gpointer data)
                                             GTK_ANCHOR_NORTH,
                                             "font", "Sans 8",
                                             "fill-color-rgba", col,
+                                            "tooltip", tooltip,
                                             NULL);
 
+    g_free (tooltip);
+
     g_object_set_data (G_OBJECT (obj->marker), "catnum", GINT_TO_POINTER (*catnum));
     g_object_set_data (G_OBJECT (obj->label), "catnum", GINT_TO_POINTER (*catnum));
 
@@ -1758,6 +1811,8 @@ update_sat (gpointer key, gpointer value, gpointer data)
     GooCanvasItemModel *root;
     gint               idx;
     guint32            col,covcol;
+    gchar    *tooltip;
+    gchar    *aosstr;
 
     //gdouble sspla,ssplo;
 
@@ -1776,6 +1831,15 @@ update_sat (gpointer key, gpointer value, gpointer data)
 
     obj = SAT_MAP_OBJ (g_hash_table_lookup (satmap->obj, catnum));
 
+    if (obj == NULL) {
+        /* FIXME: protection against this should be implemented in the module. */
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s:%d: NULL object for %d (yes, this is a bug)"),
+                     __FILE__, __LINE__, sat->tle.catnr);
+
+        return;
+    }
+
     if (obj->selected) {
         /* update satmap->sel */
         update_selected (satmap, sat);
@@ -1785,6 +1849,23 @@ update_sat (gpointer key, gpointer value, gpointer data)
     //sat->ssplon = ssplo;
     //sat->ssplat = sspla;
 
+    /* we update tooltips every time */
+    aosstr = aoslos_time_to_str(satmap, sat);
+    tooltip = g_strdup_printf("<big><b>%s</b>\n</big>"\
+                              "<tt>Lon: %5.1f\302\260\n" \
+                              "Lat: %5.1f\302\260\n" \
+                              " Az: %5.1f\302\260\n" \
+                              " El: %5.1f\302\260\n" \
+                              "%s</tt>",
+                              sat->nickname,
+                              sat->ssplon, sat->ssplat,
+                              sat->az, sat->el,
+                              aosstr);
+    g_object_set (obj->marker, "tooltip", tooltip, NULL);
+    g_object_set (obj->label, "tooltip", tooltip, NULL);
+    g_free (tooltip);
+    g_free (aosstr);
+
     lonlat_to_xy (satmap, sat->ssplon, sat->ssplat, &x, &y);
 
     /* update only if satellite has moved at least
@@ -1803,6 +1884,10 @@ update_sat (gpointer key, gpointer value, gpointer data)
                       "x", (gdouble) (x - MARKER_SIZE_HALF),
                       "y", (gdouble) (y - MARKER_SIZE_HALF),
                       NULL);
+        g_object_set (obj->shadowm,
+                      "x", (gdouble) (x - MARKER_SIZE_HALF + 1),
+                      "y", (gdouble) (y - MARKER_SIZE_HALF + 1),
+                      NULL);
 
         /* update sat label */
         if (x < 50) {
@@ -1811,24 +1896,44 @@ update_sat (gpointer key, gpointer value, gpointer data)
                           "y", (gdouble) (y),
                           "anchor", GTK_ANCHOR_WEST,
                           NULL);
+            g_object_set (obj->shadowl,
+                          "x", (gdouble) (x+3+1),
+                          "y", (gdouble) (y+1),
+                          "anchor", GTK_ANCHOR_WEST,
+                          NULL);
         } else if ((satmap->width - x ) < 50) {
             g_object_set (obj->label,
-                          "x", (gdouble) (x),
+                          "x", (gdouble) (x-3),
                           "y", (gdouble) (y),
                           "anchor", GTK_ANCHOR_EAST,
                           NULL);
+            g_object_set (obj->shadowl,
+                          "x", (gdouble) (x-3+1),
+                          "y", (gdouble) (y+1),
+                          "anchor", GTK_ANCHOR_EAST,
+                          NULL);
         } else if ((satmap->height - y) < 25) {
             g_object_set (obj->label,
                           "x", (gdouble) (x),
                           "y", (gdouble) (y-2),
                           "anchor", GTK_ANCHOR_SOUTH,
                           NULL);
+            g_object_set (obj->shadowl,
+                          "x", (gdouble) (x+1),
+                          "y", (gdouble) (y-2+1),
+                          "anchor", GTK_ANCHOR_SOUTH,
+                          NULL);
         } else {
             g_object_set (obj->label,
                           "x", (gdouble) (x),
                           "y", (gdouble) (y+2),
                           "anchor", GTK_ANCHOR_NORTH,
                           NULL);
+            g_object_set (obj->shadowl,
+                          "x", (gdouble) (x+1),
+                          "y", (gdouble) (y+2+1),
+                          "anchor", GTK_ANCHOR_NORTH,
+                          NULL);
         }
 
         /* initialize points for footprint */
@@ -2238,3 +2343,42 @@ gtk_sat_map_reload_sats (GtkWidget *satmap, GHashTable *sats)
     GTK_SAT_MAP (satmap)->ncat = 0;
 }
 
+
+
+/** \brief Convert AOS or LOS timestamp to human readable countdown string */
+static gchar *aoslos_time_to_str (GtkSatMap *satmap, sat_t *sat)
+{
+    guint    h,m,s;
+    gdouble  number, now;
+    gchar   *text = NULL;
+
+
+    now = satmap->tstamp;//get_current_daynum ();
+    if (sat->el > 0.0) {
+        number = sat->los - now;
+    }
+    else {
+        number = sat->aos - now;
+    }
+
+    /* convert julian date to seconds */
+    s = (guint) (number * 86400);
+
+    /* extract hours */
+    h = (guint) floor (s/3600);
+    s -= 3600*h;
+
+    /* extract minutes */
+    m = (guint) floor (s/60);
+    s -= 60*m;
+
+
+    if (sat->el > 0.0) {
+        text = g_strdup_printf (_("LOS in %d minutes"), m+60*h);
+    }
+    else {
+        text = g_strdup_printf (_("AOS in %d minutes"), m+60*h);
+    }
+
+    return text;
+}
