@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -91,7 +91,9 @@ typedef struct {
     
     /* graphical elements */
     GooCanvasItemModel  *marker;  /*!< A small rectangle showing sat pos. */
+    GooCanvasItemModel  *shadowm; /*!< Shadow under satellite marker. */
     GooCanvasItemModel  *label;   /*!< Satellite name. */
+    GooCanvasItemModel  *shadowl; /*!< Shadow under satellite name */
     GooCanvasItemModel  *range1;  /*!< First part of the range circle. */
     GooCanvasItemModel  *range2;  /*!< Second part of the range circle. */
     
