@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2010  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -49,12 +49,13 @@ typedef enum {
 
 
 /** \brief Module layout */
-typedef enum {
-    GTK_SAT_MOD_LAYOUT_1 = 0, /*!< one view */
-    GTK_SAT_MOD_LAYOUT_2,     /*!< Two views, one above the other */
-    GTK_SAT_MOD_LAYOUT_3,     /*!< Three views, big one on top, two small one at bottom */
-    GTK_SAT_MOD_LAYOUT_4      /*!< Three views, big one on bottom, small ones on top */
-} gtk_sat_mod_layout_t;
+
+//typedef enum {
+//    GTK_SAT_MOD_LAYOUT_1 = 0, /*!< one view */
+//    GTK_SAT_MOD_LAYOUT_2,     /*!< Two views, one above the other */
+//    GTK_SAT_MOD_LAYOUT_3,     /*!< Three views, big one on top, two small one at bottom */
+//    GTK_SAT_MOD_LAYOUT_4      /*!< Three views, big one on bottom, small ones on top */
+//} gtk_sat_mod_layout_t;
 
 
 /** \brief View types */
@@ -63,14 +64,15 @@ typedef enum {
     GTK_SAT_MOD_VIEW_MAP,       /*!< GtkSatMap */
     GTK_SAT_MOD_VIEW_POLAR,     /*!< GtkPolarView */
     GTK_SAT_MOD_VIEW_SINGLE,    /*!< GtkSingleSat */
-    GTK_SAT_MOD_VIEW_MET,       /*!< GtkMet */
+    GTK_SAT_MOD_VIEW_EVENT,     /*!< GtkEventList */
+    GTK_SAT_MOD_VIEW_NUM,       /*!< Number of modules */
 } gtk_sat_mod_view_t;
 
 
 
 #define GTK_TYPE_SAT_MODULE         (gtk_sat_module_get_type ())
 #define GTK_SAT_MODULE(obj)         GTK_CHECK_CAST (obj,\
-                                    gtk_sat_module_get_type (),	\
+                                    gtk_sat_module_get_type (),     \
                                     GtkSatModule)
 
 #define GTK_SAT_MODULE_CLASS(klass) GTK_CHECK_CLASS_CAST (klass,\
@@ -95,9 +97,12 @@ struct _gtk_sat_module
     GtkWidget     *win;       /*!< Window when module is not docked */
 
     GtkWidget     *rotctrlwin;  /*!< Rotator controller window */
-    GtkWidget     *rotctrl;
+    GtkWidget     *rotctrl;     /*!< Rotator controller widget */
     GtkWidget     *rigctrlwin;  /*!< Radio controller window */
-    GtkWidget     *rigctrl;
+    GtkWidget     *rigctrl;     /*!< Radio controller widget */
+    GtkWidget     *skgwin;      /*!< Sky at glance window */
+    GtkWidget     *skg;         /*!< Sky at glance widget */
+    gdouble        lastSkgUpd;  /*!< Daynum of last GtkSkyGlance update */
 
     GtkWidget     *header;
     guint          head_count;
@@ -105,18 +110,10 @@ struct _gtk_sat_module
     guint          event_count;
     guint          event_timeout;
 
-    /* layout */
-    GtkWidget     *vpaned;      /*!< Vertical space divider */
-    GtkWidget     *hpaned;      /*!< Horizontal space divider */
-
-    /* these are needed when docking */
-    gint           vpanedpos;   /*!< Stored position of vpaned */
-    gint           hpanedpos;   /*!< Stored pos of hpaned */
-
-    /* children */
-    GtkWidget     *child_1;
-    GtkWidget     *child_2;
-    GtkWidget     *child_3;
+    /* layout and children */
+    gint         *grid;         /*!< The grid layout array [(type,left,right,top,bottom),...] */
+    guint         nviews;       /*!< The number of views */
+    GSList       *views;        /*!< Pointers to the views */
 
     GKeyFile      *cfgdata;      /*!< Configuration data. */
     qth_t         *qth;          /*!< QTH information. */
@@ -126,16 +123,11 @@ struct _gtk_sat_module
     guint32        timeout;      /*!< Timeout value [msec] */
 
     gtk_sat_mod_state_t  state;   /*!< The state of the module. */
-    gtk_sat_mod_layout_t layout;  /*!< module layout */
-    gtk_sat_mod_view_t   view_1;
-    gtk_sat_mod_view_t   view_2;
-    gtk_sat_mod_view_t   view_3;
 
     guint          timerid;      /*!< The timeout ID (FIXME: REMOVE) */
-    gboolean       busy;         /*!< Flag indicating whether timeout has
-                                                                      finished or not. Also used for blocking
-                                                                          the module during TLE update.
-                                                                 */
+    GMutex        *busy;         /*!< Flag indicating whether timeout has
+                                      finished or not. Also used for blocking
+                                      the module during TLE update. */
 
     /* time keeping */
     gdouble        rtNow;        /*!< Real-time in this cycle */
