@@ -1,10 +1,11 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2011  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <oz9aec@gmail.com>
+           Charles Suprin <hamaa1vs@gmail.com>
 
   Comments, questions and bugreports should be submitted via
   http://sourceforge.net/projects/gpredict/
@@ -28,6 +29,10 @@
 /** \brief Satellite selector.
  *
  */
+
+/*needed _gnu_source to have strcasestr defined*/
+#define _GNU_SOURCE
+#include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #ifdef HAVE_CONFIG_H
@@ -42,10 +47,6 @@
 
 
 
-
-
-
-
 static void gtk_sat_selector_class_init (GtkSatSelectorClass *class);
 static void gtk_sat_selector_init       (GtkSatSelector *selector);
 static void gtk_sat_selector_destroy    (GtkObject *object);
@@ -58,10 +59,14 @@ static void row_activated_cb            (GtkTreeView *view,
                                          GtkTreeViewColumn *column,
                                          gpointer data);
 
+static gboolean cb_entry_changed( GtkEditable *entry, GtkTreeView *treeview );
 static gint compare_func (GtkTreeModel *model,
                           GtkTreeIter  *a,
                           GtkTreeIter  *b,
                           gpointer      userdata);
+static gboolean sat_filter_func( GtkTreeModel *model, 
+                                 GtkTreeIter  *iter, 
+                                 GtkEntry     *entry );
 
 
 static void epoch_cell_data_function (GtkTreeViewColumn *col,
@@ -70,6 +75,8 @@ static void epoch_cell_data_function (GtkTreeViewColumn *col,
                                       GtkTreeIter       *iter,
                                       gpointer           column);
 
+static gint cat_file_compare (const gchar *a, const gchar *b);
+static void gtk_sat_selector_mark_engine(GtkSatSelector *selector, gint catnr,gboolean val);
 
 static GtkVBoxClass *parent_class = NULL;
 
@@ -83,6 +90,36 @@ enum {
 /** \brief GtkSatSelector specific signals. */
 static guint gtksatsel_signals[LAST_SIGNAL] = { 0 };
 
+gboolean gtk_sat_selector_search_equal_func (GtkTreeModel *model, 
+                                             gint column,
+                                             const gchar *key,
+                                             GtkTreeIter *iter,
+                                             gpointer search_data)
+{
+    gchar *name = NULL;
+    gchar *match;
+    //gchar *NULLSTR = "NULL";
+
+    gtk_tree_model_get(model, iter, GTK_SAT_SELECTOR_COL_NAME, &name, -1);
+    /* sat_log_log(SAT_LOG_LEVEL_MSG, "%s: key %s, name %s", */
+    /*             __FUNCTION__,  */
+    /*             key,  */
+    /*             (name==NULL) ? NULLSTR : name);  */ 
+    if (name == NULL){
+        sat_log_log(SAT_LOG_LEVEL_MSG, "%s:%s: name is NULL", __FILE__, __FUNCTION__); 
+        return TRUE;
+    }
+    match = strstr(name, key);
+
+    if (match == NULL) {
+        //sat_log_log(SAT_LOG_LEVEL_BUG, "%s: no match", __FUNCTION__);
+        return TRUE;
+    } 
+    else {
+        //sat_log_log(SAT_LOG_LEVEL_BUG, "%s: MATCH at %s", __FUNCTION__, match);
+        return FALSE;
+    }
+}
 
 GType gtk_sat_selector_get_type ()
 {
@@ -190,7 +227,7 @@ GtkWidget *gtk_sat_selector_new (guint flags)
     GtkTreeViewColumn  *column;
     GtkWidget          *table;
     GtkWidget          *frame;
-
+    GtkTreeModel *filter;
 
     if (!flags)
         flags = GTK_SAT_SELECTOR_DEFAULT_FLAGS;
@@ -208,14 +245,12 @@ GtkWidget *gtk_sat_selector_new (guint flags)
     /* combo box signal handler will be connected at the end after it has
        been populated to avoid false triggering */
 
+    /*create search widget early so it can be used for callback*/
+    GTK_SAT_SELECTOR (widget)->search = gtk_entry_new ();
 
     /* create list and model */
-    selector->tree = gtk_tree_view_new ();
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (selector->tree), TRUE);
     create_and_fill_models (selector);
     model = GTK_TREE_MODEL (g_slist_nth_data (selector->models, 0));
-    gtk_tree_view_set_model (GTK_TREE_VIEW (selector->tree), model);
-    g_object_unref (model);
 
     /* sort the tree by name */
     gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
@@ -227,6 +262,21 @@ GtkWidget *gtk_sat_selector_new (guint flags)
                                           GTK_SAT_SELECTOR_COL_NAME,
                                           GTK_SORT_ASCENDING);
 
+    /*create a filtering tree*/
+    filter = gtk_tree_model_filter_new(model,NULL);
+    gtk_tree_model_filter_set_visible_func(GTK_TREE_MODEL_FILTER(filter), 
+                                           (GtkTreeModelFilterVisibleFunc) sat_filter_func,GTK_SAT_SELECTOR(widget)->search,NULL);
+
+    selector->tree = gtk_tree_view_new_with_model(filter);
+    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (selector->tree), TRUE);
+
+    g_signal_connect( G_OBJECT(GTK_SAT_SELECTOR(widget)->search), "changed",
+                      G_CALLBACK(cb_entry_changed),
+                      GTK_TREE_VIEW( selector->tree));
+
+    g_object_unref (model);
+
+
     /* we can now connect combobox signal handler */
     g_signal_connect (GTK_SAT_SELECTOR (widget)->groups, "changed",
                       G_CALLBACK(group_selected_cb), widget);
@@ -282,19 +332,16 @@ GtkWidget *gtk_sat_selector_new (guint flags)
 
     table = gtk_table_new (7, 4, TRUE);
 
-    /* Search */    
+    /* Search */
+    /* Finish setting up the search entry*/
     gtk_table_attach (GTK_TABLE (table), gtk_label_new (_("Search")), 0, 1, 0, 1,
                       GTK_SHRINK, GTK_SHRINK, 0, 0);
-    GTK_SAT_SELECTOR (widget)->search = gtk_entry_new ();
     gtk_widget_set_tooltip_text (GTK_SAT_SELECTOR (widget)->search,
                                  _("Start typing in this field to search for a satellite"\
                                    " in the selected group."));
 
-    /* this enables automatic search */
-    gtk_tree_view_set_search_entry (GTK_TREE_VIEW (GTK_SAT_SELECTOR (widget)->tree),
-                                    GTK_ENTRY (GTK_SAT_SELECTOR (widget)->search));
     gtk_table_attach (GTK_TABLE (table), GTK_SAT_SELECTOR (widget)->search, 1, 4, 0, 1,
-                      GTK_FILL, GTK_SHRINK, 0, 0);
+                      GTK_SHRINK, GTK_SHRINK, 0, 0);
 
     /* Group selector */
     gtk_table_attach (GTK_TABLE (table), gtk_label_new (_("Group")), 0, 1, 1, 2,
@@ -348,9 +395,11 @@ static void create_and_fill_models (GtkSatSelector *selector)
 
     gchar       **buffv;
     const gchar  *fname;
+    gchar        *nfname;
 
     guint         num = 0;
-
+    gint          i,n;
+    GSList       *cats = NULL;
 
 
 
@@ -358,7 +407,8 @@ static void create_and_fill_models (GtkSatSelector *selector)
     store = gtk_list_store_new (GTK_SAT_SELECTOR_COL_NUM,
                                 G_TYPE_STRING,    // name
                                 G_TYPE_INT,       // catnum
-                                G_TYPE_DOUBLE     // epoch
+                                G_TYPE_DOUBLE,    // epoch
+                                G_TYPE_BOOLEAN    // selected
                                 );
     selector->models = g_slist_append (selector->models, store);
     gtk_combo_box_append_text (GTK_COMBO_BOX (selector->groups), _("All satellites"));
@@ -382,7 +432,7 @@ static void create_and_fill_models (GtkSatSelector *selector)
         */
     while ((fname = g_dir_read_name (dir))) {
 
-        if (g_strrstr (fname, ".sat")) {
+        if (g_str_has_suffix (fname, ".sat")) {
 
             buffv = g_strsplit (fname, ".", 0);
             catnum = (gint) g_ascii_strtoll (buffv[0], NULL, 0);
@@ -398,6 +448,7 @@ static void create_and_fill_models (GtkSatSelector *selector)
                                     GTK_SAT_SELECTOR_COL_NAME, sat.nickname,
                                     GTK_SAT_SELECTOR_COL_CATNUM, catnum,
                                     GTK_SAT_SELECTOR_COL_EPOCH, sat.jul_epoch,
+                                    GTK_SAT_SELECTOR_COL_SELECTED, FALSE,
                                     -1);
 
                 g_free (sat.name);
@@ -415,13 +466,22 @@ static void create_and_fill_models (GtkSatSelector *selector)
     /* load satellites from each .cat file into selector->models[i] */
     g_dir_rewind (dir);
     while ((fname = g_dir_read_name (dir))) {
-        if (g_strrstr (fname, ".cat")) {
-
-            load_cat_file (selector, fname);
-
+        if (g_str_has_suffix (fname, ".cat")) {
+            cats = g_slist_insert_sorted(cats,g_strdup(fname),(GCompareFunc)cat_file_compare);
         }
     }
 
+    /*now load them into the combo box*/
+    n = g_slist_length (cats);
+    for (i = 0; i < n; i++) {
+        nfname = g_slist_nth_data (cats, i);
+        if (nfname) {
+            load_cat_file (selector, nfname);
+        }
+        g_free(nfname);
+    }
+    g_slist_free (cats);
+
     g_dir_close (dir);
     g_free (dirname);
 
@@ -472,7 +532,8 @@ static void load_cat_file (GtkSatSelector *selector, const gchar *fname)
             store = gtk_list_store_new (GTK_SAT_SELECTOR_COL_NUM,
                                         G_TYPE_STRING,    // name
                                         G_TYPE_INT,       // catnum
-                                        G_TYPE_DOUBLE     // epoch
+                                        G_TYPE_DOUBLE,    // epoch
+                                        G_TYPE_BOOLEAN    // selected
                                         );
             selector->models = g_slist_append (selector->models, store);
 
@@ -503,6 +564,7 @@ static void load_cat_file (GtkSatSelector *selector, const gchar *fname)
                                         GTK_SAT_SELECTOR_COL_NAME, sat.nickname,
                                         GTK_SAT_SELECTOR_COL_CATNUM, catnum,
                                         GTK_SAT_SELECTOR_COL_EPOCH, sat.jul_epoch,
+                                        GTK_SAT_SELECTOR_COL_SELECTED, FALSE,
                                         -1);
                     g_free (sat.name);
                     g_free (sat.nickname);
@@ -576,6 +638,7 @@ static void group_selected_cb (GtkComboBox *combobox, gpointer data)
     GtkSatSelector *selector = GTK_SAT_SELECTOR (data);
     GtkTreeModel   *newmodel;
     GtkTreeModel   *oldmodel;
+    GtkTreeModel   *filter;
     gint            sel;
 
     sel = gtk_combo_box_get_active (combobox);
@@ -589,13 +652,25 @@ static void group_selected_cb (GtkComboBox *combobox, gpointer data)
 
     /* now replace oldmodel with newmodel */
     newmodel = GTK_TREE_MODEL (g_slist_nth_data (selector->models, sel));
-    gtk_tree_view_set_model (GTK_TREE_VIEW (selector->tree), newmodel);
-    g_object_unref (newmodel);
 
     /* We changed the GtkTreeModel so we need to reset the sort column ID */
     gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (newmodel),
                                           GTK_SAT_SELECTOR_COL_NAME,
                                           GTK_SORT_ASCENDING);
+    /*build a filter around the new model*/
+    filter = gtk_tree_model_filter_new(newmodel,NULL);
+    gtk_tree_model_filter_set_visible_func(GTK_TREE_MODEL_FILTER(filter), 
+                                           (GtkTreeModelFilterVisibleFunc) sat_filter_func,GTK_SAT_SELECTOR(selector)->search,NULL);
+
+    /*install the filter tree and hookup callbacks*/
+    gtk_tree_view_set_model (GTK_TREE_VIEW (selector->tree), filter);
+    g_signal_connect( G_OBJECT(GTK_SAT_SELECTOR(selector)->search), "changed",
+                      G_CALLBACK(cb_entry_changed),
+                      GTK_TREE_VIEW( selector->tree));
+    g_object_unref (newmodel);
+    g_object_unref (filter);
+
+
 
 
 }
@@ -734,3 +809,183 @@ static void epoch_cell_data_function (GtkTreeViewColumn *col,
     }
 
 }
+
+
+
+/** \brief Get the latest EPOCH of the satellites that are loaded into the GtkSatSelector.
+  * \param selector Pointer to the GtkSatSelector widget.
+  * \return The latest EPOCH or 0.0 in case an error occurs.
+  */
+gdouble gtk_sat_selector_get_latest_epoch (GtkSatSelector *selector)
+{
+    GtkTreeModel *model;
+    GtkTreeIter   iter;
+    gdouble epoch = 0.0;
+    gdouble thisepoch;
+    gint i,n;
+
+
+    g_return_val_if_fail (selector != 0 && IS_GTK_SAT_SELECTOR (selector), 0.0);
+
+
+    /* get the tree model that contains all satellites */
+    model = GTK_TREE_MODEL (g_slist_nth_data (selector->models, 0));
+    n = gtk_tree_model_iter_n_children (model,NULL);
+
+    /* loop over each satellite in the model and store the newest EPOCH */
+    for (i = 0; i < n; i++) {
+        if G_LIKELY(gtk_tree_model_iter_nth_child (model, &iter, NULL, i)) {
+            gtk_tree_model_get (model, &iter,
+                                GTK_SAT_SELECTOR_COL_EPOCH, &thisepoch,
+                                -1);
+            if (thisepoch > epoch)
+                epoch = thisepoch;
+
+        }
+        else {
+            sat_log_log (SAT_LOG_LEVEL_ERROR,
+                         _("%s: Error getting %dth satellite"), __FUNCTION__, i);
+        }
+    }
+
+    return epoch;
+}
+
+
+/** \brief Load category name from a .cat file
+ *  \param fname The name of the .cat file (name only, no path)
+ *  This function is a stripped down version of load_cat_file.  It 
+ *  is needed to load the category name to created a sorted list 
+ *  of category names. With the existing user base already having 
+ *  .cat files in their directories, use of the file name directly 
+ *  for sorting will have problems.
+ */
+static gchar *load_cat_file_cat (const gchar *fname)
+{
+    GIOChannel   *catfile;
+    GError       *error = NULL;
+
+    gchar        *path;
+    gchar        *buff;
+
+    /* .cat files contains clear text category name in the first line
+               then one satellite catalog number per line */
+    path = sat_file_name (fname);
+    catfile = g_io_channel_new_file (path, "r", &error);
+    if (error != NULL) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s:%s: Failed to open %s: %s"),
+                     __FILE__, __FUNCTION__, fname, error->message);
+        g_clear_error (&error);
+    }
+    else {
+        /* read first line => category name */
+        
+        if (g_io_channel_read_line (catfile, &buff, NULL, NULL, NULL) == G_IO_STATUS_NORMAL) {
+            g_strstrip (buff); /* removes trailing newline */
+        }
+    }
+    
+    g_free (path);
+    g_io_channel_shutdown (catfile, TRUE, NULL);
+    return buff;
+}
+
+/* this is a quick function that loads the category name from two cat 
+   files and compares them. 
+*/
+gint cat_file_compare (const gchar *a,const gchar *b){
+    gchar *cat_a, *cat_b;
+    gint temp;
+    
+    cat_a = load_cat_file_cat (a);
+    cat_b = load_cat_file_cat (b);
+    temp = g_ascii_strcasecmp (cat_a,cat_b);
+    g_free (cat_a);
+    g_free (cat_b);
+    return (temp);
+        
+}
+
+/** \brief Make the tree refilter after something entered in the search box
+ **/
+
+static gboolean cb_entry_changed( GtkEditable *entry,
+                  GtkTreeView *treeview )
+{
+    GtkTreeModelFilter *filter;
+   
+    filter = GTK_TREE_MODEL_FILTER( gtk_tree_view_get_model( treeview ) );
+    gtk_tree_model_filter_refilter( filter );
+   
+    return( FALSE );
+} 
+
+/** \brief Selects unselected satellites whose name contains the substring in entry.
+ **/
+static gboolean sat_filter_func( GtkTreeModel *model, 
+                                 GtkTreeIter  *iter, 
+                                 GtkEntry     *entry )
+{
+    const gchar *searchstring;
+    gchar       *satname;
+    gboolean     selected;
+   
+    gtk_tree_model_get( model, iter, GTK_SAT_SELECTOR_COL_NAME, &satname, -1 );
+    gtk_tree_model_get( model, iter, GTK_SAT_SELECTOR_COL_SELECTED, &selected, -1 );
+    searchstring = gtk_entry_get_text( entry );
+    /*if it is already selected then remove it from the available list*/
+    if (selected)
+        return( FALSE);
+    if( strcasestr( satname, searchstring ) != (char *)NULL )
+        return( TRUE );
+    else
+        return( FALSE );
+} 
+
+/** \brief Searches through all the models for the given satellite and sets its selected value.
+    \param *selector is the selector that contains the models
+    \param catnr is the catalog numer of satellite.
+    \param val is true or false depending on whether that satellite is selected or not.
+ **/
+static void gtk_sat_selector_mark_engine(GtkSatSelector *selector, gint catnr,gboolean val){
+    gint n, k;
+    gint nummodels, numiters;
+    gint catnumscratch;
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+
+    nummodels = g_slist_length(selector->models);
+
+    for (n = 0; n<nummodels; n++) {
+        model = GTK_TREE_MODEL(g_slist_nth_data (selector->models,n));
+        numiters = gtk_tree_model_iter_n_children(model,NULL);
+        for (k = 0; k<numiters; k++){
+            if (G_LIKELY(gtk_tree_model_iter_nth_child(model, &iter,NULL,k))){                    
+                gtk_tree_model_get (model, &iter, GTK_SAT_SELECTOR_COL_CATNUM, &catnumscratch,-1);
+                if (catnumscratch == catnr) {
+                    gtk_list_store_set(GTK_LIST_STORE(model),&iter,GTK_SAT_SELECTOR_COL_SELECTED,val,-1);
+                }
+            }
+        
+        }
+    
+    }
+}
+
+
+/** \brief Searches the models for the satellite and sets SELECTED to TRUE.
+    \param *selector is the selector that contains the models
+    \param catnr is the catalog numer of satellite.
+**/
+void gtk_sat_selector_mark_selected(GtkSatSelector *selector, gint catnr){
+    gtk_sat_selector_mark_engine ( selector, catnr, TRUE);
+}
+
+/** \brief Searches the models for the satellite and sets SELECTED to FALSE.
+    \param *selector is the selector that contains the models
+    \param catnr is the catalog numer of satellite.
+**/
+void gtk_sat_selector_mark_unselected(GtkSatSelector *selector, gint catnr){
+    gtk_sat_selector_mark_engine ( selector, catnr, FALSE);
+}
