@@ -1,10 +1,11 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2011  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <oz9aec@gmail.com>
+           Charles Suprin <hamaa1vs@gmail.com>
 
   Comments, questions and bugreports should be submitted via
   http://sourceforge.net/projects/gpredict/
@@ -118,7 +119,7 @@ static void gtk_single_sat_popup_cb (GtkWidget *button, gpointer data);
 static void select_satellite        (GtkWidget *menuitem, gpointer data);
 static void show_next_pass_cb       (GtkWidget *menuitem, gpointer data);
 static void show_next_passes_cb     (GtkWidget *menuitem, gpointer data);
-
+static gint sat_name_compare (sat_t *a,sat_t *b);
 
 static GtkVBoxClass *parent_class = NULL;
 
@@ -724,7 +725,7 @@ store_sats (gpointer key, gpointer value, gpointer user_data)
     GtkSingleSat *single_sat = GTK_SINGLE_SAT (user_data);
     sat_t        *sat = SAT (value);
 
-    single_sat->sats = g_slist_append (single_sat->sats, sat);
+    single_sat->sats = g_slist_insert_sorted (single_sat->sats,sat, (GCompareFunc) sat_name_compare);
 }
 
 
@@ -791,7 +792,6 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
 {
     GtkSingleSat *single_sat = GTK_SINGLE_SAT (data);
     GtkWidget    *menu;
-    GtkWidget    *select_menu;
     GtkWidget    *menuitem;
     GtkWidget    *image;
     GtkWidget    *label;
@@ -824,7 +824,7 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
     g_object_set_data (G_OBJECT (menuitem), "sat", sat);
     g_object_set_data (G_OBJECT (menuitem), "qth", single_sat->qth);
     g_signal_connect (menuitem, "activate",
-                      G_CALLBACK (show_sat_info),
+                      G_CALLBACK (show_sat_info_menu_cb),
                       gtk_widget_get_toplevel (button));
 
     gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
@@ -833,7 +833,7 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
     menuitem = gtk_separator_menu_item_new ();
     gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
-    /* next pass and predict passes */
+    /* Show next pass */
     menuitem = gtk_image_menu_item_new_with_label (_("Show next pass"));
     image = gtk_image_new_from_stock (GTK_STOCK_JUSTIFY_FILL,
                                       GTK_ICON_SIZE_MENU);
@@ -848,6 +848,7 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
     
     gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
         
+    /* Show future passes */
     menuitem = gtk_image_menu_item_new_with_label (_("Future passes"));
     image = gtk_image_new_from_stock (GTK_STOCK_INDEX,
                                       GTK_ICON_SIZE_MENU);
@@ -879,8 +880,7 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
     menuitem = gtk_separator_menu_item_new ();
     gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
-    select_menu = gtk_menu_new ();
-
+    /* select sat */
     for (i = 0; i < n; i++) {
 
         sati = SAT (g_slist_nth_data (single_sat->sats, i));
@@ -899,16 +899,12 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
         g_signal_connect_after (menuitem, "activate",
                                 G_CALLBACK (select_satellite), single_sat);
 
-        gtk_menu_shell_append (GTK_MENU_SHELL (select_menu), menuitem);
+        //gtk_menu_shell_append (GTK_MENU_SHELL (select_menu), menuitem);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
         //gtk_widget_show (menuitem);
     }
 
 
-    /* select sat */
-    menuitem = gtk_menu_item_new_with_label (_("Select satellite"));
-    gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), select_menu);
-    gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
-
     gtk_widget_show_all (menu);
 
     /* Note: event can be NULL here when called from view_onPopupMenu;
@@ -1150,3 +1146,7 @@ show_next_passes_cb     (GtkWidget *menuitem, gpointer data)
      }
 
 }
+
+static gint sat_name_compare (sat_t *a,sat_t *b) {
+    return g_ascii_strcasecmp(a->nickname,b->nickname);
+}
