@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2010  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -26,10 +26,13 @@
   along with this program; if not, visit http://www.fsf.org/
 */
 /** \brief Sky at a glance Widget.
+ * 
+ * The sky at a glance widget provides a convenient overview of the upcoming
+ * satellite passes in a timeline format. The widget is tied to a specific
+ * module and uses the QTH and satellite data from the module.
  *
  * Note about the sizing policy:
- * Initially we require 30 pixels per sat + 5 pix margin between the sats.
- * Additionally.
+ * Initially we require 10 pixels per sat + 5 pix margin between the sats.
  *
  * When we get additional space due to resizing, the space will be allocated
  * to make the rectangles taller.
@@ -46,6 +49,7 @@
 #include "gtk-sat-data.h"
 #include "gpredict-utils.h"
 #include "predict-tools.h"
+#include "sat-pass-dialogs.h"
 #include "time-tools.h"
 //#include "gtk-sky-glance-popup.h"
 #include "gtk-sky-glance.h"
@@ -87,14 +91,24 @@ static gboolean on_button_release      (GooCanvasItem *item,
                                         GdkEventButton *event,
                                         gpointer data);
 
+static gboolean on_mouse_enter         (GooCanvasItem    *item,
+                                        GooCanvasItem    *target_item,
+                                        GdkEventCrossing *event,
+                                        gpointer          data);
+static gboolean on_mouse_leave         (GooCanvasItem    *item,
+                                        GooCanvasItem    *target_item,
+                                        GdkEventCrossing *event,
+                                        gpointer          data);
+
+
 static GooCanvasItemModel* create_canvas_model (GtkSkyGlance *skg);
 
 
-static gdouble t2x (GtkSkyGlance *skg, gdouble t);
-static gdouble x2t (GtkSkyGlance *skg, gdouble x);
-
 static void create_sat (gpointer key, gpointer value, gpointer data);
 
+static gdouble t2x (GtkSkyGlance *skg, gdouble t);
+static gdouble x2t (GtkSkyGlance *skg, gdouble x);
+static gchar *time_to_str (gdouble julutc);
 
 
 static GtkVBoxClass *parent_class = NULL;
@@ -167,8 +181,13 @@ gtk_sky_glance_init (GtkSkyGlance *skg)
 }
 
 
-/* for some reason, this function is called twice when
-   parent is destroyed.
+/** \brief Destroy the GtkSkyGlance widget
+ *  \param object Pointer to the GtkSkyGlance widget
+ *
+ * This function is called when the GtkSkyGlance widget is destroyed. It frees 
+ * the memory that has been allocated when the widget was created.
+ * 
+ * \bug For some reason, this function is called twice when parent is destroyed.
  */
 static void
 gtk_sky_glance_destroy (GtkObject *object)
@@ -195,7 +214,7 @@ gtk_sky_glance_destroy (GtkObject *object)
     /* for the rest we only need to free the GSList because the
         canvas items will be freed when removed from canvas.
     */
-    if (GTK_SKY_GLANCE (object)->satlab != NULL) {	
+    if (GTK_SKY_GLANCE (object)->satlab != NULL) {     
         g_slist_free (GTK_SKY_GLANCE (object)->satlab);
         GTK_SKY_GLANCE (object)->satlab = NULL;
     }
@@ -221,6 +240,7 @@ gtk_sky_glance_destroy (GtkObject *object)
 /** \brief Create a new GtkSkyGlance widget.
  *  \param sats Pointer to the hash table containing the asociated satellites.
  *  \param qth Pointer to the ground station data.
+ *  \param ts The t0 for the timeline or 0 to use the current date and time.
  */
 GtkWidget*
 gtk_sky_glance_new (GHashTable *sats, qth_t *qth, gdouble ts)
@@ -269,19 +289,20 @@ gtk_sky_glance_new (GHashTable *sats, qth_t *qth, gdouble ts)
 
     /* create the canvas */
     GTK_SKY_GLANCE (skg)->canvas = goo_canvas_new ();
+    g_object_set (G_OBJECT (GTK_SKY_GLANCE(skg)->canvas), "has-tooltip", TRUE, NULL);
     gtk_widget_modify_base (GTK_SKY_GLANCE (skg)->canvas, GTK_STATE_NORMAL, &bg_color);
     gtk_widget_set_size_request (GTK_SKY_GLANCE (skg)->canvas,
-                                    GTK_SKY_GLANCE (skg)->w,
-                                    GTK_SKY_GLANCE (skg)->h + SKG_FOOTER);
+                                 GTK_SKY_GLANCE (skg)->w,
+                                 GTK_SKY_GLANCE (skg)->h + SKG_FOOTER);
     goo_canvas_set_bounds (GOO_CANVAS (GTK_SKY_GLANCE (skg)->canvas), 0, 0,
-                            GTK_SKY_GLANCE (skg)->w,
-                            GTK_SKY_GLANCE (skg)->h + SKG_FOOTER);
+                           GTK_SKY_GLANCE (skg)->w,
+                           GTK_SKY_GLANCE (skg)->h + SKG_FOOTER);
 
     /* connect size-request signal */
     g_signal_connect (GTK_SKY_GLANCE (skg)->canvas, "size-allocate",
-                        G_CALLBACK (size_allocate_cb), skg);
+                      G_CALLBACK (size_allocate_cb), skg);
     g_signal_connect (GTK_SKY_GLANCE (skg)->canvas, "item_created",
-                        (GtkSignalFunc) on_item_created, skg);
+                      (GtkSignalFunc) on_item_created, skg);
     g_signal_connect_after (GTK_SKY_GLANCE (skg)->canvas, "realize",
                             (GtkSignalFunc) on_canvas_realized, skg);
 
@@ -303,6 +324,9 @@ gtk_sky_glance_new (GHashTable *sats, qth_t *qth, gdouble ts)
 }
 
 
+/** \brief Create the model for the GtkSkyGlance canvas
+ *  \param skg Pointer to the GtkSkyGlance widget
+ */
 static GooCanvasItemModel *
 create_canvas_model (GtkSkyGlance *skg)
 {
@@ -564,11 +588,11 @@ size_allocate_cb (GtkWidget *widget, GtkAllocation *allocation, gpointer data)
             }
 
             g_object_set (skp->box,
-                            "x", x,
-                            "y", y,
-                            "width", w,
-                            "height", h,
-                            NULL);
+                          "x", x,
+                          "y", y,
+                          "width", w,
+                          "height", h,
+                          NULL);
         }
 
     }
@@ -597,9 +621,9 @@ on_canvas_realized (GtkWidget *canvas, gpointer data)
 /** \brief Manage mouse motion events. */
 static gboolean
 on_motion_notify (GooCanvasItem *item,
-                    GooCanvasItem *target,
-                    GdkEventMotion *event,
-                    gpointer data)
+                  GooCanvasItem *target,
+                  GdkEventMotion *event,
+                  gpointer data)
 {
     GtkSkyGlance    *skg = GTK_SKY_GLANCE (data);
     GooCanvasPoints *pts;
@@ -633,7 +657,9 @@ on_motion_notify (GooCanvasItem *item,
     /* in order to avoid label clipping close to the edges of
         the chart, the label is placed left/right of the cursor
         tracking line depending on which half we are in.
+        => Currently disabled, time display stays in upper left corner
     */
+/*
     if (event->x > (skg->w / 2)) {
         g_object_set (skg->timel,
                         "text", buff,
@@ -648,15 +674,21 @@ on_motion_notify (GooCanvasItem *item,
                         "anchor", GTK_ANCHOR_NW,
                         NULL);
     }
+*/
+    g_object_set (skg->timel,
+                  "text", buff,
+                  NULL);
+
+
 
     return TRUE;
 }
 
 
 /** \brief Finish canvas item setup.
- *  \param canvas 
- *  \param item
- *  \param model 
+ *  \param canvas Pointer to the GooCanvas object
+ *  \param item Pointer to the GooCanvasItem that received the signals
+ *  \param model Pointer to the model associated with the GooCanvasItem object
  *  \param data Pointer to the GtkSkyGlance object.
  *
  * This function is called when a canvas item is created. Its purpose is to connect
@@ -668,32 +700,35 @@ on_item_created (GooCanvas *canvas,
                 GooCanvasItemModel *model,
                 gpointer data)
 {
-    if (!goo_canvas_item_model_get_parent (model))	{
+    if (!goo_canvas_item_model_get_parent (model))     {
         /* root item / canvas */
-        g_signal_connect (item, "motion_notify_event",
-                            (GtkSignalFunc) on_motion_notify, data);
+        g_signal_connect (item, "motion_notify_event", (GtkSignalFunc) on_motion_notify, data);
     }
 
     else if (!g_object_get_data (G_OBJECT (item), "skip-signal-connection")) {
-        g_signal_connect (item, "button_press_event",
-                            (GtkSignalFunc) on_button_press, data);
-        g_signal_connect (item, "button_release_event",
-                            (GtkSignalFunc) on_button_release, data);
+        //g_signal_connect (item, "button_press_event", (GtkSignalFunc) on_button_press, data);
+        g_signal_connect (item, "button_release_event", (GtkSignalFunc) on_button_release, data);
+        g_signal_connect (item, "enter_notify_event", (GtkSignalFunc) on_mouse_enter, data);
+        g_signal_connect (item, "leave_notify_event", (GtkSignalFunc) on_mouse_leave, data);
     }
 }
 
 
 /** \brief Manage button press events
+ *  \param item The GooCanvasItem object that received the button press event.
+ *  \param target The target of the event (what?).
+ *  \param event Event data, such as X and Y coordinates.
+ *  \param data User data; points to the GtkSkyAtGlance object.
+ *  \return Always TRUE to prevent further propagation of the event.
  *
- * This function is called when a mouse button is pressed on a satellite object.
- * If the pressed button is #3 (right button) the satellite popup menu will be
- * created and executed.
+ * This function is called when a mouse button is pressed on a satellite pass object.
+ * If the pressed button is 1 (left) pass details will be show.
  */
 static gboolean
 on_button_press (GooCanvasItem *item,
-                GooCanvasItem *target,
-                GdkEventButton *event,
-                gpointer data)
+                 GooCanvasItem *target,
+                 GdkEventButton *event,
+                 gpointer data)
 {
 /*  GooCanvasItemModel *model = goo_canvas_item_get_model (item); */
 /*  GtkSkyGlance  *skg = GTK_SKY_GLANCE (data); */
@@ -701,56 +736,139 @@ on_button_press (GooCanvasItem *item,
 
     switch (event->button) {
 
-        /* pop-up menu */
-    case 3:
-
-        break;
-
     default:
-        break;
-    }
-
-       
-
-	return TRUE;
-}
-
-
-/** \brief Manage button release events.
- *
- * This function is called when the mouse button is released above
- * a satellite object. It will act as a button click and if the relesed
- * button is the left one, the clock will correspond to selecting or
- * deselecting a satellite
- */
-static gboolean
-on_button_release (GooCanvasItem *item,
-                    GooCanvasItem *target,
-                    GdkEventButton *event,
-                    gpointer data)
-{
-/*  GooCanvasItemModel *model = goo_canvas_item_get_model (item); */
-/*  GtkSkyGlance  *skg = GTK_SKY_GLANCE (data); */
-
-    switch (event->button) {
-
-        /* Select / de-select satellite */
-    case 1:
+        sat_log_log (SAT_LOG_LEVEL_DEBUG,
+                     _("%s::%s: Button %d has no function..."),
+                     __FILE__, __FUNCTION__, event->button);
 
         break;
-
-    default:
-        break;
-    }
-
+    }       
 
     return TRUE;
 }
 
 
+/** \brief Manage button release events.
+ *  \param item The GooCanvasItem object that received the button press event.
+ *  \param target The target of the event (what?).
+ *  \param event Event data, such as X and Y coordinates.
+ *  \param data User data; points to the GtkSkyAtGlance object.
+ *  \return Always TRUE to prevent further propagation of the event.
+ *
+ * This function is called when the mouse button is released above
+ * a satellite pass object.
+ *
+ * We do not currently use this for anything.
+ */
+static gboolean
+on_button_release (GooCanvasItem *item,
+                   GooCanvasItem *target,
+                   GdkEventButton *event,
+                   gpointer data)
+{
+
+    GooCanvasItemModel *item_model = goo_canvas_item_get_model (item);
+    GtkSkyGlance  *skg = GTK_SKY_GLANCE (data);
+
+    /* get pointer to pass_t structure */
+    pass_t *pass = (pass_t *) g_object_get_data(G_OBJECT(item_model), "pass");
+    pass_t *new_pass;
+
+
+    if G_UNLIKELY(pass == NULL) {
+        sat_log_log (SAT_LOG_LEVEL_BUG,
+                     _("%s::%s: Could not retrieve pass_t object"),
+                     __FILE__, __FUNCTION__);
+        return TRUE;
+    }
+
+
+    switch (event->button) {
+
+        /* LEFT button released */
+    case 1:
+        new_pass = copy_pass (pass);
+        sat_log_log (SAT_LOG_LEVEL_BUG,
+                     _("%s::%s: Showing pass details for %s - we may have a memory leak here"),
+                     __FILE__, __FUNCTION__, pass->satname);
+
+        /* show the pass details */
+        show_pass (pass->satname, skg->qth, new_pass, NULL);
+
+        break;
+
+    default:
+        sat_log_log (SAT_LOG_LEVEL_DEBUG,
+                     _("%s::%s: Button %d has no function..."),
+                     __FILE__, __FUNCTION__, event->button);
+        break;
+    }
+
+    return TRUE;
+}
+
+
+/** \brief Manage mouse-enter events on canvas items (satellite pass boxes)
+ * \param item The GooCanvasItem that received the signal
+ * \param target_item The target if the even (have no idea what this is...)
+ * \param event Info about the event
+ * \param data Pointer to the GtkSkyAtGlance object
+ * \return Always TRUE to prevent further propagation of the event.
+ *
+ * This function is used to be notified when the mouse enters over a satellite
+ * pass box. We could use it to highlihght the pass under the mouse.
+ */
+static gboolean on_mouse_enter         (GooCanvasItem    *item,
+                                        GooCanvasItem    *target_item,
+                                        GdkEventCrossing *event,
+                                        gpointer          data)
+{
+    GooCanvasItemModel *item_model = goo_canvas_item_get_model (item);
+    GtkSkyGlance  *skg = GTK_SKY_GLANCE (data);
+
+    /* get pointer to pass_t structure */
+    pass_t *pass = (pass_t *) g_object_get_data(G_OBJECT(item_model), "pass");
+    if G_UNLIKELY(pass == NULL) {
+        sat_log_log (SAT_LOG_LEVEL_BUG,
+                     _("%s::%s: Could not retrieve pass_t object"),
+                     __FILE__, __FUNCTION__);
+        return TRUE;
+    }
+
+    //g_print("Mouse enter: %s AOS:\n");
+
+    return TRUE;
+}
+
+
+/** \brief Manage mouse-leave events on canvas items (satellite pass boxes)
+ * \param item The GooCanvasItem that received the signal
+ * \param target_item The target if the even (have no idea what this is...)
+ * \param event Info about the event
+ * \param data Pointer to the GtkSkyAtGlance object
+ * \return Always TRUE to prevent further propagation of the event.
+ *
+ * This function is used to be notified when the mouse leaves a satellite
+ * pass box.
+ */
+static gboolean on_mouse_leave         (GooCanvasItem    *item,
+                                        GooCanvasItem    *target_item,
+                                        GdkEventCrossing *event,
+                                        gpointer          data)
+{
+    //g_print("Mouse leave\n");
+
+    return TRUE;
+}
+
+
+
+
+
 /** \brief Convert time value to x position.
  *  \param skg The GtkSkyGlance widget.
- *  \param t Julian date
+ *  \param t Julian dateuser is presented with brief info about the
+ * satellite pass and a suggestion to click on the box for more info.
  *  \return X coordinate.
  *
  * No error checking is made to ensure that we are within visible range.
@@ -785,7 +903,7 @@ static gdouble x2t (GtkSkyGlance *skg, gdouble x)
 }
 
 
-/* fetch the basic colour and add alpha channel */
+/** \brief Fetch the basic colour and add alpha channel */
 static void get_colours (guint i, guint *bcol, guint *fcol)
 {
     guint tmp;
@@ -847,7 +965,7 @@ static void get_colours (guint i, guint *bcol, guint *fcol)
     *bcol = (tmp * 0x100) | 0xFF;
 
     /* fill colour is slightly transparent */
-    *fcol = (tmp * 0x100) | 0xF0;
+    *fcol = (tmp * 0x100) | 0xA0;
 }
 
 
@@ -874,15 +992,21 @@ create_sat (gpointer key, gpointer value, gpointer data)
     GooCanvasItemModel *root;
     GooCanvasItemModel *lab;
 
+    /* tooltips vars */
+    gchar *tooltip; /* the complete tooltips string */
+    gchar *aosstr;  /* AOS time string */
+    gchar *losstr;  /* LOS time string */
+    gchar *tcastr;  /* TCA time string */
+
 
     /* FIXME: 
         Include current pass if sat is up now
     */
 
     /* check that we didn't exceed 10 sats */
-    /* 	if (++skg->satcnt > 10) { */
-    /* 		return; */
-    /* 	} */
+    /*      if (++skg->satcnt > 10) { */
+    /*           return; */
+    /*      } */
 
     /* get canvas root */
     root = goo_canvas_get_root_item_model (GOO_CANVAS (skg->canvas));
@@ -912,13 +1036,42 @@ create_sat (gpointer key, gpointer value, gpointer data)
                 skypass->catnum = sat->tle.catnr;
                 tmppass = (pass_t *) g_slist_nth_data (passes, i);
                 skypass->pass = copy_pass (tmppass);
+
+                aosstr = time_to_str (skypass->pass->aos);
+                losstr = time_to_str (skypass->pass->los);
+                tcastr = time_to_str (skypass->pass->tca);
+
+                /* box tooltip will contain pass summary */
+                tooltip = g_strdup_printf("<big><b>%s</b>\n</big>\n"\
+                                          "<tt>AOS: %s  Az:%.0f\302\260\n" \
+                                          "TCA: %s  Az:%.0f\302\260 / El:%.1f\302\260\n" \
+                                          "LOS: %s  Az:%.0f\302\260</tt>\n" \
+                                          "\n<i>Click for details</i>",
+                                          skypass->pass->satname,
+                                          aosstr, skypass->pass->aos_az,
+                                          tcastr, skypass->pass->maxel_az, skypass->pass->max_el,
+                                          losstr, skypass->pass->los_az);
+
+                g_free (aosstr);
+                g_free (losstr);
+                g_free (tcastr);
+
                 skypass->box = goo_canvas_rect_model_new (root, 10, 10, 20, 20, /* dummy coordinates */
-                                                            "stroke-color-rgba", bcol,
-                                                            "fill-color-rgba", fcol,
-                                                            NULL);
-                                                    
-                /* store pass data */
+                                                          "stroke-color-rgba", bcol,
+                                                          "fill-color-rgba", fcol,
+                                                          "line-width", 1.0,
+                                                          "antialias", CAIRO_ANTIALIAS_NONE,
+                                                          "tooltip", tooltip,
+                                                          NULL);
+                g_free (tooltip);
+
+                /* store this pass in list */
                 skg->passes = g_slist_append (skg->passes, skypass);
+
+                /* store a pointer to the pass data in the GooCanvasItem so that we
+                   can access it later during various events, e.g mouse click */
+                g_object_set_data (G_OBJECT (skypass->box), "pass", skypass->pass);
+
             }
             else {
                 sat_log_log (SAT_LOG_LEVEL_ERROR,
@@ -939,3 +1092,47 @@ create_sat (gpointer key, gpointer value, gpointer data)
         skg->satlab = g_slist_append (skg->satlab, lab);
     }
 }
+
+
+
+/** \brief Convert "jul_utc" time to formatted string
+  * \param julutc The time to convert
+  * \return A newly allocated string containing the formatted time (should be freed by caller)
+  *
+  * \bug This code is duplicated many places.
+  */
+static gchar *time_to_str (gdouble julutc)
+{
+    gchar   buff[TIME_FORMAT_MAX_LENGTH];
+    gchar  *fmtstr;
+    gchar  *timestr;
+    time_t  t;
+    guint   size;
+
+
+    /* convert julian date to struct time_t */
+    t = (julutc - 2440587.5)*86400.;
+
+    /* format the number */
+    fmtstr = sat_cfg_get_str (SAT_CFG_STR_TIME_FORMAT);
+
+    /* format either local time or UTC depending on check box */
+    if (sat_cfg_get_bool (SAT_CFG_BOOL_USE_LOCAL_TIME)) {
+        size = strftime (buff, TIME_FORMAT_MAX_LENGTH, fmtstr, localtime (&t));
+    }
+    else {
+        size = strftime (buff, TIME_FORMAT_MAX_LENGTH, fmtstr, gmtime (&t));
+    }
+
+    g_free (fmtstr);
+
+
+    if (size == 0)
+        /* size > MAX_LENGTH */
+        buff[TIME_FORMAT_MAX_LENGTH-1] = '\0';
+
+    timestr = g_strdup (buff);
+
+
+    return timestr;
+}
