@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2010  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -29,21 +29,15 @@
  *  \ingroup main
  *  \bief    Main program file.
  *
- * Add some more text.
- *
- * \bug Change to glib getopt in 2.6
- *
  */
 #include <stdlib.h>
 #include <signal.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #ifdef HAVE_CONFIG_H
 #  include <build-config.h>
 #endif
-#ifdef HAVE_GETOPT_H
-#  include <getopt.h>
-#endif
 #include "sat-log.h"
 #include "first-time.h"
 #include "compat.h"
@@ -51,12 +45,33 @@
 #include "mod-mgr.h"
 #include "tle-update.h"
 #include "sat-cfg.h"
+#include "gtk-sat-selector.h"
 #include "sat-debugger.h"
 
+#ifdef WIN32
+#include <winsock2.h>
+#endif
+
 /** \brief Main application widget. */
 GtkWidget *app;
 
 
+/** \brief Command line flag for cleaning TLE data. */
+static gboolean cleantle = FALSE;
+
+/** \brief Command line flag for cleaning TRSP data */
+static gboolean cleantrsp = FALSE;
+
+/** \brief Command line options. */
+static GOptionEntry entries[] =
+{
+  { "clean-tle", 0, 0, G_OPTION_ARG_NONE, &cleantle, "Clean the TLE data in user's configuration directory", NULL },
+  { "clean-trsp", 0, 0, G_OPTION_ARG_NONE, &cleantrsp, "Clean the transponder data in user's configuration directory", NULL },
+  { NULL }
+};
+
+
+
 const gchar *dummy = N_("just to have a pot");
 
 
@@ -79,14 +94,22 @@ static void     gpredict_sig_handler  (int sig);
 static gboolean tle_mon_task          (gpointer data);
 static void     tle_mon_stop          (void);
 static gpointer update_tle_thread     (gpointer data);
+static void     clean_tle             (void);
+static void     clean_trsp            (void);
 
-static void test_ui (void);
+#ifdef G_OS_WIN32
+  static void InitWinSock2(void);
+  static void CloseWinSock2(void);
+#endif
 
 
 int main (int argc, char *argv[])
 {
+    GError *err = NULL;
+    GOptionContext *context;
     guint  error = 0;
 
+
 #ifdef G_OS_WIN32
     printf ("Starting gpredict. This may take some time...\n");
 #endif
@@ -97,11 +120,33 @@ int main (int argc, char *argv[])
     bind_textdomain_codeset (PACKAGE, "UTF-8");
     textdomain (PACKAGE);
 #endif
-    gtk_set_locale ();
     gtk_init (&argc, &argv);
 
+    context = g_option_context_new ("");
+    g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
+    g_option_context_set_summary (context,
+                                  _("Gpredict is a graphical real-time satellite tracking "\
+                                    "and orbit prediction program.\n"\
+                                    "Gpredict does not require any command line options for "\
+                                    "nominal operation."));
+    g_option_context_add_group (context, gtk_get_option_group (TRUE));
+    if (!g_option_context_parse (context, &argc, &argv, &err)) {
+        g_print (_("Option parsing failed: %s\n"), err->message);
+    }
+
+
     /* start logger first, so that we can catch error messages if any */
     sat_log_init ();
+     
+    if (!g_thread_supported ())
+        g_thread_init (NULL);
+
+    /* check command line options */
+    if (cleantle)
+        clean_tle ();
+
+    if (cleantrsp)
+        clean_trsp ();
 
     /* check that user settings are ok */
     error = first_time_check_run ();
@@ -131,23 +176,61 @@ int main (int argc, char *argv[])
     /* launch TLE monitoring task; 10 min interval */
     tle_mon_id = g_timeout_add (600000, tle_mon_task, NULL);
 
-    //test_ui ();
+     
+#ifdef WIN32
+     // Initializing Windozze Sockets
+    InitWinSock2();
+#endif
     
     gtk_main ();
 
+     g_option_context_free(context);
+#ifdef WIN32
+    // Cleanup Windozze Sockets
+    CloseWinSock2();
+#endif
     return 0;
 }
 
-static void test_ui (void)
+#ifdef WIN32
+/* This code was given from MSDN */
+static void InitWinSock2(void)
 {
-    gchar *fnam;
-    
-    fnam = g_strconcat (g_get_home_dir(), G_DIR_SEPARATOR_S,
-                        "test.ui", NULL);
-    
-    g_free (fnam);
+    WORD wVersionRequested;
+    WSADATA wsaData;
+    int err;
+
+    wVersionRequested = MAKEWORD( 2, 2 );
+
+    err = WSAStartup( wVersionRequested, &wsaData );
+    if ( err != 0 ) {
+        /* Tell the user that we could not find a usable */
+        /* WinSock DLL.                                  */
+        return;
+    }
+
+    /* Confirm that the WinSock DLL supports 2.2.*/
+    /* Note that if the DLL supports versions later    */
+    /* than 2.2 in addition to 2.2, it will still return */
+    /* 2.2 in wVersion since that is the version we      */
+    /* requested.                                        */
+
+    if ( LOBYTE( wsaData.wVersion ) != 2 ||
+         HIBYTE( wsaData.wVersion ) != 2 ) {
+        /* Tell the user that we could not find a usable */
+        /* WinSock DLL.                                  */
+        WSACleanup( );
+        return;
+    }
 }
 
+static void CloseWinSock2(void)
+{
+    WSACleanup();
+}
+#endif
+
+
 
 /** \brief Create main application window.
  *  \return A new top level window as as GtkWidget.
@@ -227,8 +310,8 @@ static void gpredict_app_create ()
 static void
 gpredict_sig_handler (int sig)
 {
-    /* 	satlog_log (SAT_LOG_ERROR, "Received signal: %d\n", sig); */
-    /* 	satlog_log (SAT_LOG_ERROR, "Trying clean exit...\n"); */
+    /*      satlog_log (SAT_LOG_ERROR, "Received signal: %d\n", sig); */
+    /*      satlog_log (SAT_LOG_ERROR, "Trying clean exit...\n"); */
 
     gtk_widget_destroy (app);
 }
@@ -281,7 +364,7 @@ gpredict_app_destroy    (GtkWidget *widget,
     mod_mgr_save_state ();
 
     /* not good, have to use configure event instead (see API doc) */
-    /*	gtk_window_get_size (GTK_WINDOW (app), &w, &h);
+    /*     gtk_window_get_size (GTK_WINDOW (app), &w, &h);
                 sat_cfg_set_int (SAT_CFG_INT_WINDOW_WIDTH, w);
                 sat_cfg_set_int (SAT_CFG_INT_WINDOW_HEIGHT, h);
         */
@@ -363,18 +446,27 @@ gpredict_app_config   (GtkWidget *widget, GdkEventConfigure *event, gpointer dat
 static gboolean
 tle_mon_task          (gpointer data)
 {
+    /*GtkWidget *selector;*/
     glong last,now,thrld;
     GTimeVal   tval;
     GtkWidget *dialog;
     GError    *err = NULL;
 
 
-    /* 	sat_log_log (SAT_LOG_LEVEL_DEBUG, */
-    /* 				 _("%s: Checking whether TLE check should be executed..."), */
-    /* 				 __FUNCTION__); */
+    /*      sat_log_log (SAT_LOG_LEVEL_DEBUG, */
+    /*                      _("%s: Checking whether TLE check should be executed..."), */
+    /*                      __FUNCTION__); */
 
     /* get time of last update */
     last = sat_cfg_get_int (SAT_CFG_INT_TLE_LAST_UPDATE);
+    /*if (last == 0) {
+        selector = gtk_sat_selector_new (0);
+        last = (glong) gtk_sat_selector_get_latest_epoch (GTK_SAT_SELECTOR (selector));
+        gtk_widget_destroy (selector);
+    }
+
+    g_print ("LAST: %ld\n", last); */
+
 
     /* get current time */
     g_get_current_time (&tval);
@@ -403,9 +495,9 @@ tle_mon_task          (gpointer data)
 
     if ((now - last) < thrld) {
         /* too early */
-        /* 		sat_log_log (SAT_LOG_LEVEL_DEBUG, */
-        /* 					 _("%s: Threshold has not been passed yet."), */
-        /* 					 __FUNCTION__, last, now, thrld); */
+        /*           sat_log_log (SAT_LOG_LEVEL_DEBUG, */
+        /*                           _("%s: Threshold has not been passed yet."), */
+        /*                           __FUNCTION__, last, now, thrld); */
     }
     else {
         /* time to update */
@@ -421,8 +513,6 @@ tle_mon_task          (gpointer data)
                          _("%s: Starting new update thread."),
                          __FUNCTION__);
 
-            if (!g_thread_supported ())
-                g_thread_init (NULL);
 
             g_thread_create (update_tle_thread, NULL, FALSE, &err);
 
@@ -494,3 +584,85 @@ update_tle_thread     (gpointer data)
 
     return NULL;
 }
+
+
+/** \brief Clean TLE data.
+  *
+  * This function removes all .sat files from the user's configuration directory.
+  * The function is called when gpreidict is executed with the --clean-tle
+  * command line option.
+  */
+static void clean_tle (void)
+{
+    GDir     *targetdir;
+    gchar    *targetdirname,*path;
+    const gchar *filename;
+
+
+    /* Get trsp directory */
+    targetdirname = get_satdata_dir ();
+    targetdir = g_dir_open (targetdirname, 0, NULL);
+
+    sat_log_log (SAT_LOG_LEVEL_MSG,
+                 _("%s: Cleaning TLE data in %s"), __FUNCTION__, targetdirname);
+
+
+    while ((filename = g_dir_read_name (targetdir))) {
+        if (g_str_has_suffix (filename, ".sat")) {
+            /* remove .sat file */
+            path = sat_file_name (filename);
+            if G_UNLIKELY(g_unlink (path)) {
+                sat_log_log (SAT_LOG_LEVEL_ERROR,
+                             _("%s: Failed to delete %s"), __FUNCTION__, filename);
+            }
+            else {
+                sat_log_log (SAT_LOG_LEVEL_MSG,
+                             _("%s: Removed %s"), __FUNCTION__, filename);
+            }
+            g_free (path);
+        }
+    }
+    g_free (targetdirname);
+
+}
+
+
+/** \brief Clean transponder data.
+  *
+  * This function removes all .trsp files from the user's configuration directory.
+  * The function is called when gpredict is executed with the --clean-trsp
+  * command line option.
+  */
+static void clean_trsp (void)
+{
+    GDir     *targetdir;
+    gchar    *targetdirname,*path;
+    const gchar *filename;
+
+
+    /* Get trsp directory */
+    targetdirname = get_trsp_dir ();
+    targetdir = g_dir_open (targetdirname, 0, NULL);
+
+    sat_log_log (SAT_LOG_LEVEL_MSG,
+                 _("%s: Cleaning transponder data in %s"), __FUNCTION__, targetdirname);
+
+
+    while ((filename = g_dir_read_name (targetdir))) {
+        if (g_str_has_suffix (filename, ".trsp")) {
+            /* remove .trsp file */
+            path = trsp_file_name (filename);
+            if G_UNLIKELY(g_unlink (path)) {
+                sat_log_log (SAT_LOG_LEVEL_ERROR,
+                             _("%s: Failed to delete %s"), __FUNCTION__, filename);
+            }
+            else {
+                sat_log_log (SAT_LOG_LEVEL_MSG,
+                             _("%s: Removed %s"), __FUNCTION__, filename);
+            }
+            g_free (path);
+        }
+    }
+    g_free (targetdirname);
+
+}
