@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -80,7 +80,10 @@ static void   menubar_news_cb      (GtkWidget *widget, gpointer data);
 static void   menubar_about_cb     (GtkWidget *widget, gpointer data);
 static gchar *select_module        (void);
 static void   create_module_window (GtkWidget *module);
-
+static gint compare_func (GtkTreeModel *model,
+                          GtkTreeIter  *a,
+                          GtkTreeIter  *b,
+                          gpointer      userdata);
 
 /** \brief Regular menu items.
  *  \ingroup menupriv
@@ -203,9 +206,9 @@ menubar_create (GtkWidget *window)
     GtkUIManager   *uimgr;
     GtkAccelGroup  *accgrp;
     GError         *error = NULL;
-    GtkWidget      *menuitem;
-    GtkWidget      *image;
-    gchar          *icon;
+    //GtkWidget      *menuitem;
+    //GtkWidget      *image;
+    //gchar          *icon;
     gint           i;
 
 
@@ -264,8 +267,6 @@ menubar_new_mod_cb  (GtkWidget *widget, gpointer data)
     gchar *modfile;
     gchar *confdir;
     GtkWidget *module = NULL;
-    GtkWidget *parent;
-
 
 
     sat_log_log (SAT_LOG_LEVEL_DEBUG,
@@ -305,14 +306,6 @@ menubar_new_mod_cb  (GtkWidget *widget, gpointer data)
         }
         else {
             mod_mgr_add_module (module, TRUE);
-
-            /* get size allocation from parent and set some reasonable
-               initial GtkPaned positions
-            */
-            parent = gtk_widget_get_parent (module);
-            GTK_SAT_MODULE (module)->hpanedpos = parent->allocation.width / 2;
-            GTK_SAT_MODULE (module)->vpanedpos = parent->allocation.height / 2;
-            gtk_sat_module_fix_size (module);
         }
 
         g_free (modnam);
@@ -333,7 +326,6 @@ menubar_open_mod_cb  (GtkWidget *widget, gpointer data)
     gchar *modfile;
     gchar *confdir;
     GtkWidget *module = NULL;
-    GtkWidget *parent;
 
 
     sat_log_log (SAT_LOG_LEVEL_DEBUG,
@@ -385,16 +377,6 @@ menubar_open_mod_cb  (GtkWidget *widget, gpointer data)
                 mod_mgr_add_module (module, FALSE);
                 create_module_window (module);
             }
-
-            //mod_mgr_add_module (module, TRUE);
-
-            /* get size allocation from parent and set some reasonable
-               initial GtkPaned positions
-            */
-            parent = gtk_widget_get_parent (module);
-            GTK_SAT_MODULE (module)->hpanedpos = parent->allocation.width / 2;
-            GTK_SAT_MODULE (module)->vpanedpos = parent->allocation.height / 2;
-            gtk_sat_module_fix_size (module);
         }
 
         g_free (modnam);
@@ -828,6 +810,8 @@ select_module        ()
     GtkTreeIter        item;       /* new item added to the list store */
     GtkTreeSelection  *selection;
     GtkTreeModel      *selmod;
+     GtkTreeModel      *listtreemodel;
+     GtkWidget         *swin;
     GDir              *dir = NULL;   /* directory handle */
     GError            *error = NULL; /* error flag and info */
     gchar             *dirname;      /* directory name */
@@ -838,8 +822,8 @@ select_module        ()
     /* create and fill data model */
     liststore = gtk_list_store_new (1, G_TYPE_STRING);
 
-    /* scan for .qth files in the user config directory and
-       add the contents of each .qth file to the list store
+    /* scan for .mod files in the user config directory and
+       add the contents of each .mod file to the list store
     */
     dirname = get_modules_dir ();
     dir = g_dir_open (dirname, 0, &error);
@@ -852,7 +836,7 @@ select_module        ()
 
         while ((filename = g_dir_read_name (dir))) {
 
-            if (g_strrstr (filename, ".mod")) {
+            if (g_str_has_suffix (filename, ".mod")) {
 
                 /* strip extension and add to list */
                 buffv = g_strsplit (filename, ".mod", 0);
@@ -897,9 +881,25 @@ select_module        ()
 
     /* create tree view */
     modlist = gtk_tree_view_new ();
-    gtk_tree_view_set_model (GTK_TREE_VIEW (modlist), GTK_TREE_MODEL (liststore));
+     listtreemodel=GTK_TREE_MODEL (liststore);
+     gtk_tree_view_set_model (GTK_TREE_VIEW (modlist), listtreemodel);
     g_object_unref (liststore);
 
+     swin = gtk_scrolled_window_new(NULL,NULL);
+     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
+                                    GTK_POLICY_AUTOMATIC,
+                                    GTK_POLICY_AUTOMATIC);
+     /* sort the tree by name */
+    gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (listtreemodel),
+                                     0,
+                                     compare_func,
+                                     NULL,
+                                     NULL);
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (listtreemodel),
+                                          0,
+                                          GTK_SORT_ASCENDING);
+
+
     /*** FIXME: Add g_stat info? */
 
     renderer = gtk_cell_renderer_text_new ();
@@ -922,8 +922,9 @@ select_module        ()
                                           NULL);
 
     gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 200);
-
-    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), modlist);
+     gtk_container_add (GTK_CONTAINER (swin), modlist);
+    gtk_widget_show (swin);
+    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), swin);
 
     switch (gtk_dialog_run (GTK_DIALOG (dialog))) {
 
@@ -1070,3 +1071,22 @@ create_module_window (GtkWidget *module)
 
 }
 
+static gint compare_func (GtkTreeModel *model,
+                          GtkTreeIter  *a,
+                          GtkTreeIter  *b,
+                          gpointer      userdata)
+{
+    gchar *sat1,*sat2;
+    gint ret = 0;
+
+
+    gtk_tree_model_get(model, a, 0, &sat1, -1);
+    gtk_tree_model_get(model, b, 0, &sat2, -1);
+
+    ret = g_ascii_strcasecmp (sat1, sat2);
+
+    g_free (sat1);
+    g_free (sat2);
+
+    return ret;
+}
