@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2011  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -64,7 +64,7 @@ static void       add_qth_cb (GtkWidget *button, gpointer data);
 
 static void       edit_advanced_settings (GtkDialog *parent, GKeyFile *cfgdata);
 
-static GtkWidget *create_selected_sats_list (GKeyFile *cfgdata, gboolean new);
+static GtkWidget *create_selected_sats_list (GKeyFile *cfgdata, gboolean new, GtkSatSelector *selector);
 static void add_selected_sat (GtkListStore *store, gint catnum);
 
 static void sat_activated_cb (GtkSatSelector *selector, gint catnr, gpointer data);
@@ -80,6 +80,7 @@ static void row_activated_cb (GtkTreeView *view, GtkTreePath *path,
 static void addbut_clicked_cb (GtkButton *button, GtkSatSelector *selector);
 static void delbut_clicked_cb (GtkButton *button, GtkSatSelector *selector);
 
+static gint qth_name_compare (const gchar *a, const gchar *b);
 
 /** \brief Create a new module.
  *
@@ -554,7 +555,7 @@ static GtkWidget *mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata
                       G_CALLBACK (sat_activated_cb), NULL);
 
     /* list of selected satellites */
-    satlist = create_selected_sats_list (cfgdata, new);
+    satlist = create_selected_sats_list (cfgdata, new, GTK_SAT_SELECTOR(selector));
     swin = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
     gtk_container_add (GTK_CONTAINER (swin), satlist);
@@ -565,7 +566,7 @@ static GtkWidget *mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata
     g_signal_connect (addbut, "clicked", G_CALLBACK (addbut_clicked_cb), selector);
     delbut = gpredict_hstock_button (GTK_STOCK_GO_BACK, NULL,
                                      _("Remove satellite from the list of selected satellites."));
-    g_signal_connect (delbut, "clicked", G_CALLBACK (delbut_clicked_cb), NULL);
+    g_signal_connect (delbut, "clicked", G_CALLBACK (delbut_clicked_cb), selector);
 
     /* quick sat selecotr tutorial label */
     label = gtk_label_new (NULL);
@@ -598,7 +599,7 @@ static GtkWidget *mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata
   * \returns A newly created GtkTreeView widget.
   *
   */
-static GtkWidget *create_selected_sats_list (GKeyFile *cfgdata, gboolean new)
+static GtkWidget *create_selected_sats_list (GKeyFile *cfgdata, gboolean new, GtkSatSelector *selector)
 {
     GtkWidget          *satlist;
     GtkCellRenderer    *renderer;
@@ -636,13 +637,14 @@ static GtkWidget *create_selected_sats_list (GKeyFile *cfgdata, gboolean new)
     /* "row-activated" signal is used to catch double click events, which means
        a satellite has been selected. This will cause the satellite to be deleted */
     g_signal_connect (GTK_TREE_VIEW (satlist), "row-activated",
-                      G_CALLBACK(row_activated_cb), NULL);
+                      G_CALLBACK(row_activated_cb), selector);
 
     /* create the model */
     store = gtk_list_store_new (GTK_SAT_SELECTOR_COL_NUM,
                                 G_TYPE_STRING,    // name
                                 G_TYPE_INT,       // catnum
-                                G_TYPE_DOUBLE     // epoch
+                                G_TYPE_DOUBLE,    // epoch
+                                G_TYPE_BOOLEAN    // selected 
                                 );
 
     /* sort the list by name */
@@ -684,6 +686,7 @@ static GtkWidget *create_selected_sats_list (GKeyFile *cfgdata, gboolean new)
         else {
             for (i = 0; i < length; i++) {
                 add_selected_sat (store, sats[i]);
+                gtk_sat_selector_mark_selected(selector, sats[i]);
             }
             g_free (sats);
         }
@@ -829,10 +832,13 @@ static GtkWidget *create_loc_selector   (GKeyFile *cfgdata)
     gchar        *dirname;
     const gchar  *filename;
     gchar        *defqth = NULL;
+    gchar        *defqthshort = NULL;
     gchar       **buffv;
     gint         idx = -1;
     gint         count = 0;
-
+    GSList      *qths=NULL;
+    gchar       *qthname;
+    gint         i,n;
 
     combo = gtk_combo_box_new_text ();
 
@@ -845,6 +851,10 @@ static GtkWidget *create_loc_selector   (GKeyFile *cfgdata)
                                         MOD_CFG_GLOBAL_SECTION,
                                         MOD_CFG_QTH_FILE_KEY,
                                         &error);
+        buffv = g_strsplit (defqth, ".qth", 0);
+        defqthshort = g_strdup(buffv[0]);
+        
+        g_strfreev(buffv);
     }
     else {
         sat_log_log (SAT_LOG_LEVEL_MSG,
@@ -852,6 +862,7 @@ static GtkWidget *create_loc_selector   (GKeyFile *cfgdata)
                      __FUNCTION__);
 
         defqth = g_strdup (_("** DEFAULT **"));
+        defqthshort = g_strdup(defqth);
     }
 
 
@@ -863,23 +874,33 @@ static GtkWidget *create_loc_selector   (GKeyFile *cfgdata)
 
     if (dir) {
         while ((filename = g_dir_read_name (dir))) {
-
-            if (g_strrstr (filename, ".qth")) {
+            /*create a sorted list then use it to load the combo box*/
+            if (g_str_has_suffix (filename, ".qth")) {
 
                 buffv = g_strsplit (filename, ".qth", 0);
-                gtk_combo_box_append_text (GTK_COMBO_BOX (combo), buffv[0]);
+                qths = g_slist_insert_sorted(qths,g_strdup(buffv[0]),(GCompareFunc) qth_name_compare);
                 g_strfreev (buffv);
 
-                /* is this the QTH for this module? */
-                if (!g_ascii_strcasecmp (defqth, filename)) {
-                    idx = count;
-                }
-
-                count++;
             }
 
         }
+        n = g_slist_length (qths);
+        for (i = 0; i < n; i++) {
+            qthname = g_slist_nth_data (qths, i);
+            if (qthname) {
+                gtk_combo_box_append_text (GTK_COMBO_BOX (combo), qthname);
 
+                /* is this the QTH for this module? */
+                /* comparison uses short name full filename*/
+                if (!g_ascii_strcasecmp (defqthshort, qthname)) {
+                    idx = count;
+                }
+                g_free(qthname);
+                count++;
+            }
+        }
+        g_slist_free(qths);
+        
     }
     else {
         sat_log_log (SAT_LOG_LEVEL_ERROR,
@@ -907,6 +928,7 @@ static GtkWidget *create_loc_selector   (GKeyFile *cfgdata)
     }
 
     g_free (defqth);
+    g_free (defqthshort);
     g_free (dirname);
     g_dir_close (dir);
 
@@ -1093,8 +1115,8 @@ static void add_qth_cb (GtkWidget *button, gpointer data)
             g_free (qth.wx);
         if (qth.qra != NULL)
             g_free (qth.qra);
-        /* 		if (qth.data != NULL) */
-        /* 			g_key_file_free (data); */
+        /*           if (qth.data != NULL) */
+        /*                g_key_file_free (data); */
     }
 }
 
@@ -1115,7 +1137,8 @@ static void sat_activated_cb (GtkSatSelector *selector, gint catnr, gpointer dat
     /* Add satellite to selected list */
     store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (satlist)));
     add_selected_sat (store, catnr);
-
+    /*tell the sat_selector it can hide that satellite */
+    gtk_sat_selector_mark_selected (selector, catnr);
 }
 
 
@@ -1166,13 +1189,17 @@ static void row_activated_cb (GtkTreeView *view, GtkTreePath *path,
     GtkTreeModel     *model;
     GtkTreeIter       iter;
     gboolean          haveselection = FALSE; /* this flag is set to TRUE if there is a selection */
-
+    gint              catnr;
+    GtkSatSelector   *selector = GTK_SAT_SELECTOR(data);
 
     /* get the selected row in the treeview */
     selection = gtk_tree_view_get_selection (view);
     haveselection = gtk_tree_selection_get_selected (selection, &model, &iter);
 
     if (haveselection) {
+        gtk_tree_model_get (model, &iter, GTK_SAT_SELECTOR_COL_CATNUM, &catnr, -1);
+        /*tell the sat_selector it can show that satellite again*/
+        gtk_sat_selector_mark_unselected ( selector, catnr);
         gtk_list_store_remove (GTK_LIST_STORE(model), &iter);
     }
 }
@@ -1197,6 +1224,8 @@ static void addbut_clicked_cb (GtkButton *button, GtkSatSelector *selector)
         /* Add satellite to selected list */
         store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (satlist)));
         add_selected_sat (store, catnum);
+        /*tell the sat_selector to hide that satellite */
+        gtk_sat_selector_mark_selected (selector,catnum);
     }
 
 }
@@ -1212,6 +1241,7 @@ static void delbut_clicked_cb (GtkButton *button, GtkSatSelector *selector)
     GtkTreeModel     *model;
     GtkTreeIter       iter;
     gboolean          haveselection = FALSE; /* this flag is set to TRUE if there is a selection */
+    gint              catnr;
 
 
     /* get the selected row in the treeview */
@@ -1219,8 +1249,15 @@ static void delbut_clicked_cb (GtkButton *button, GtkSatSelector *selector)
     haveselection = gtk_tree_selection_get_selected (selection, &model, &iter);
 
     if (haveselection) {
+        gtk_tree_model_get (model, &iter, GTK_SAT_SELECTOR_COL_CATNUM, &catnr, -1);
+        /*tell the sat_selector it can show that satellite again*/
+        gtk_sat_selector_mark_unselected ( selector, catnr);
         gtk_list_store_remove (GTK_LIST_STORE(model), &iter);
     }
 
 }
 
+
+static gint qth_name_compare (const gchar* a,const gchar *b){
+    return (g_ascii_strcasecmp(a,b));
+}
