@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -202,6 +202,9 @@ mod_mgr_add_module     (GtkWidget *module, gboolean dock)
                                              module,
                                              gtk_label_new (GTK_SAT_MODULE (module)->name));
 
+            /* allow nmodule to be dragged to different position */
+            gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK(nbook), module, TRUE);
+
             gtk_notebook_set_current_page (GTK_NOTEBOOK (nbook), page);
 
             /* send message to logger */
@@ -441,9 +444,6 @@ mod_mgr_dock_module    (GtkWidget *module)
                                          module,
                                          gtk_label_new (GTK_SAT_MODULE (module)->name));
 
-        /* fix size allocation, i.e. paned position */
-        gtk_sat_module_fix_size (module);
-
         sat_log_log (SAT_LOG_LEVEL_MSG,
                      _("%s: Docked %s into notebook (page %d)"),
                      __FUNCTION__, GTK_SAT_MODULE (module)->name, page);
