@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -39,7 +39,7 @@
 #include "sat-cfg.h"
 #include "orbit-tools.h"
 #include "predict-tools.h"
-
+#include "sat-log.h"
 
 
 /** \brief SGP4SDP4 driver for doing AOS/LOS calculations.
@@ -418,7 +418,7 @@ get_next_passes (sat_t *sat, qth_t *qth, gdouble maxdt, guint num)
  *       reversed
  */
 pass_t *
-get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
+get_pass   (sat_t *sat_in, qth_t *qth, gdouble start, gdouble maxdt)
 {
     gdouble        aos = 0.0;    /* time of AOS */
     gdouble        tca = 0.0;    /* time of TCA */
@@ -433,9 +433,12 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
     pass_detail_t *detail = NULL;
     gboolean       done = FALSE;
     guint          iter = 0;      /* number of iterations */
-
+    sat_t         *sat,sat_working;
     /* FIXME: watchdog */
 
+    /*copy sat_in to a working structure*/
+    sat = memcpy(&sat_working,sat_in,sizeof(sat_t));
+
     /* get time resolution; sat-cfg stores it in seconds */
     tres = sat_cfg_get_int (SAT_CFG_INT_PRED_RESOLUTION) / 86400.0;
 
@@ -445,7 +448,20 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
     */
     while (!done) {
 
+        /* Find los of next pass or of current pass */
+        los = find_los (sat, qth, t0, maxdt); // See if a pass is ongoing
         aos = find_aos (sat, qth, t0, maxdt);
+        /* sat_log_log(SAT_LOG_LEVEL_MSG, "%s:%s:%d: found aos %f and los %f for t0=%f", */
+        /*          __FILE__,  */
+        /*          __FUNCTION__, */
+        /*          __LINE__, */
+        /*          aos, */
+        /*          los,  */
+        /*          t0); */
+        if (aos > los) {
+            // los is from an currently happening pass, find previous aos
+            aos = find_prev_aos(sat, qth, t0);
+        }
 
         /* aos = 0.0 means no aos */
         if (aos == 0.0) {
@@ -459,7 +475,7 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
             done = TRUE;
         }
         else {
-            los = find_los (sat, qth, aos + 0.001, maxdt); // +1.5 min later
+            //los = find_los (sat, qth, aos + 0.001, maxdt); // +1.5 min later
             dt = los - aos;
 
             /* get time step, which will give us the max number of entries */
@@ -552,12 +568,14 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
                     pass->maxel_az = sat->az;
                 }
 
-                /*	g_print ("TIME: %f\tAZ: %f\tEL: %f (MAX: %f)\n", */
-                /*		 t, sat->az, sat->el, max_el); */
+                /*     g_print ("TIME: %f\tAZ: %f\tEL: %f (MAX: %f)\n", */
+                /*           t, sat->az, sat->el, max_el); */
             }
 
             pass->details = g_slist_reverse (pass->details);
 
+            /* calculate satellite data */
+            predict_calc (sat, qth, pass->los);
             /* store los_az, max_el and tca */
             pass->los_az = sat->az;
             pass->max_el = max_el;
@@ -619,7 +637,6 @@ get_passes (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt, guint num)
     t = start;
 
     for (i = 0; i < num; i++) {
-
         pass = get_pass (sat, qth, t, maxdt);
 
         if (pass != NULL) {
@@ -643,6 +660,10 @@ get_passes (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt, guint num)
     if (passes != NULL)
         passes = g_slist_reverse (passes);
 
+    sat_log_log (SAT_LOG_LEVEL_MSG,
+                 _("%s: Found %d passes for %s in time window [%f;%f]"),
+                 __FUNCTION__, g_slist_length (passes), sat->nickname, start, start+maxdt);
+
     return passes;
 }
 
@@ -658,6 +679,7 @@ copy_pass         (pass_t *pass)
     if (new != NULL) {
         new->aos = pass->aos;
         new->los = pass->los;
+        new->tca = pass->tca;
         new->max_el = pass->max_el;
         new->aos_az = pass->aos_az;
         new->los_az = pass->los_az;
@@ -738,15 +760,19 @@ copy_pass_detail  (pass_detail_t *detail)
 void
 free_pass   (pass_t *pass)
 {
-    free_pass_details (pass->details);
-
-    if (pass->satname != NULL) {
-        g_free (pass->satname);
-        pass->satname = NULL;
-    }
-
-    g_free (pass);
-    pass = NULL;
+     if (pass!=NULL){
+     free_pass_details (pass->details);
+     
+     if (pass->satname != NULL) {
+          g_free (pass->satname);
+          pass->satname = NULL;
+     }
+     
+     g_free (pass);
+     pass = NULL;
+     } else {
+          /*FIXME: log an error?*/
+     }
 }
 
 
@@ -839,7 +865,7 @@ free_pass_details (GSList *details)
  *       reversed
  */
 pass_t *
-get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
+get_pass_no_min_el (sat_t *sat_in, qth_t *qth, gdouble start, gdouble maxdt)
 {
     gdouble        aos = 0.0;    /* time of AOS */
     gdouble        tca = 0.0;    /* time of TCA */
@@ -853,10 +879,13 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
     pass_t        *pass = NULL;
     pass_detail_t *detail = NULL;
     gboolean       done = FALSE;
-
+    sat_t         *sat,sat_working;
 
     /* FIXME: watchdog */
 
+    /*copy sat_in to a working structure*/
+    sat = memcpy(&sat_working,sat_in,sizeof(sat_t));
+
     /* get time resolution; sat-cfg stores it in seconds */
     tres = sat_cfg_get_int (SAT_CFG_INT_PRED_RESOLUTION) / 86400.0;
 
@@ -957,7 +986,7 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
             default:
                 break;
             }
-
+            
             pass->details = g_slist_prepend (pass->details, detail);
 
             /* store elevation if greater than the
@@ -969,12 +998,14 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
                 pass->maxel_az = sat->az;
             }
 
-            /*	g_print ("TIME: %f\tAZ: %f\tEL: %f (MAX: %f)\n", */
-            /*		 t, sat->az, sat->el, max_el); */
+            /*     g_print ("TIME: %f\tAZ: %f\tEL: %f (MAX: %f)\n", */
+            /*           t, sat->az, sat->el, max_el); */
         }
 
         pass->details = g_slist_reverse (pass->details);
 
+        /* calculate satellite data */
+        predict_calc (sat, qth, pass->los);
         /* store los_az, max_el and tca */
         pass->los_az = sat->az;
         pass->max_el = max_el;
@@ -1005,16 +1036,28 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
  *
  */
 pass_t *
-get_current_pass (sat_t *sat, qth_t *qth, gdouble start)
+get_current_pass (sat_t *sat_in, qth_t *qth, gdouble start)
 {
     gdouble t;
-
+    sat_t  *sat,sat_working;
+    
+    /*copy sat_in to a working structure*/
+    sat = memcpy(&sat_working,sat_in,sizeof(sat_t));
 
     if (start > 0.0)
         t = start;
     else
         t = get_current_daynum ();
-    predict_calc (sat, qth, t);	
+    predict_calc (sat, qth, t);     
+
+     /* check whether satellite has aos */
+    if ((sat->otype == ORBIT_TYPE_GEO) || 
+        (sat->otype == ORBIT_TYPE_DECAYED) ||
+          !has_aos (sat, qth)) {
+          
+        return NULL;
+          
+    }
 
     /* find a time before AOS */
     while (sat->el > -2.0) {
