@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -124,7 +124,7 @@ sat_cfg_bool_t sat_cfg_bool[SAT_CFG_BOOL_NUM] = {
     { "MODULES", "MAP_QTH_INFO",       TRUE},
     { "MODULES", "MAP_NEXT_EVENT",     TRUE},
     { "MODULES", "MAP_CURSOR_TRACK",   FALSE},
-    { "MODULES", "MAP_SHOW_GRID",      FALSE},
+    { "MODULES", "MAP_SHOW_GRID",      TRUE},
     { "MODULES", "MAP_KEEP_RATIO",     FALSE},
     { "MODULES", "POLAR_QTH_INFO",     TRUE},
     { "MODULES", "POLAR_NEXT_EVENT",   TRUE},
@@ -144,10 +144,10 @@ sat_cfg_int_t sat_cfg_int[SAT_CFG_INT_NUM] = {
     { "VERSION", "MAJOR", 0},
     { "VERSION", "MINOR", 0},
     { "MODULES", "DATA_TIMEOUT", 300},
-    { "MODULES", "LAYOUT", GTK_SAT_MOD_LAYOUT_3},
-    { "MODULES", "VIEW_1", GTK_SAT_MOD_VIEW_MAP},
-    { "MODULES", "VIEW_2", GTK_SAT_MOD_VIEW_POLAR},
-    { "MODULES", "VIEW_3", GTK_SAT_MOD_VIEW_SINGLE},
+    { "MODULES", "LAYOUT", 2},  /* FIXME */
+    { "MODULES", "VIEW_1", GTK_SAT_MOD_VIEW_MAP}, /* FIXME */
+    { "MODULES", "VIEW_2", GTK_SAT_MOD_VIEW_POLAR}, /* FIXME */
+    { "MODULES", "VIEW_3", GTK_SAT_MOD_VIEW_SINGLE}, /* FIXME */
     { "GLOBAL",  "WARP", 1},
     { "MODULES", "LIST_REFRESH", 1},
     { "MODULES", "LIST_COLUMNS", LIST_COLUMNS_DEFAULTS},
@@ -158,10 +158,11 @@ sat_cfg_int_t sat_cfg_int[SAT_CFG_INT_NUM] = {
     { "MODULES", "MAP_SAT_COLOUR", 0xF0F000FF}, 
     { "MODULES", "MAP_SELECTED_SAT_COLOUR", 0xFFFFFFFF},
     { "MODULES", "MAP_COV_AREA_COLOUR", 0xFFFFFF1F},
-    { "MODULES", "MAP_GRID_COLOUR", 0x7F7F7F7F},
-    { "MODULES", "MAP_TICK_COLOUR", 0x7F7F7F7F},
-    { "MODULES", "MAP_TRACK_COLOUR", 0x00FFFFFF},
-    { "MODULES", "MAP_TRACK_NUM", 1},
+    { "MODULES", "MAP_GRID_COLOUR", 0x7F7F7FC8},
+    { "MODULES", "MAP_TICK_COLOUR", 0x7F7F7FC8},
+    { "MODULES", "MAP_TRACK_COLOUR", 0xFF1200BB},
+    { "MODULES", "MAP_TRACK_NUM", 3},
+    { "MODULES", "MAP_SHADOW_ALPHA", 0xDD},
     { "MODULES", "POLAR_REFRESH", 3},
     { "MODULES", "POLAR_CHART_ORIENT", POLAR_VIEW_NESW},
     { "MODULES", "POLAR_BGD_COLOUR", 0xFFFFFFFF},
@@ -173,6 +174,7 @@ sat_cfg_int_t sat_cfg_int[SAT_CFG_INT_NUM] = {
     { "MODULES", "POLAR_INFO_COLOUR", 0x00007FFF},
     { "MODULES", "SINGLE_SAT_REFRESH", 1},
     { "MODULES", "SINGLE_SAT_FIELDS", SINGLE_SAT_FIELD_DEF},
+    { "MODULES", "EVENT_LIST_REFRESH", 1},
     { "PREDICT", "MINIMUM_ELEV", 5},
     { "PREDICT", "NUMBER_OF_PASSES", 10},
     { "PREDICT", "LOOK_AHEAD", 3},
@@ -184,26 +186,26 @@ sat_cfg_int_t sat_cfg_int[SAT_CFG_INT_NUM] = {
     { "PREDICT", "SAVE_CONTENTS", 0},
     { "PREDICT", "TWILIGHT_THRESHOLD", -6},
     { "SKY_AT_GLANCE", "TIME_SPAN_HOURS", 8},
-{ "SKY_AT_GLANCE", "COLOUR_01", 0x3c46c8},
-{ "SKY_AT_GLANCE", "COLOUR_02", 0x00500a},
-{ "SKY_AT_GLANCE", "COLOUR_03", 0xd5472b},
-{ "SKY_AT_GLANCE", "COLOUR_04", 0xd06b38},
-{ "SKY_AT_GLANCE", "COLOUR_05", 0xcf477a},
-{ "SKY_AT_GLANCE", "COLOUR_06", 0xbf041f},
-{ "SKY_AT_GLANCE", "COLOUR_07", 0x04bf20},
-{ "SKY_AT_GLANCE", "COLOUR_08", 0x0420bf},
-{ "SKY_AT_GLANCE", "COLOUR_09", 0xa304bf},
-{ "SKY_AT_GLANCE", "COLOUR_10", 0x04bdbf},
-{ "GLOBAL",  "WINDOW_POS_X", 0},
-{ "GLOBAL",  "WINDOW_POS_Y", 0},
-{ "GLOBAL",  "WINDOW_WIDTH", 700},
-{ "GLOBAL",  "WINDOW_HEIGHT", 700},
-{ "GLOBAL",  "HTML_BROWSER_TYPE", 0},
-{ "TLE",     "AUTO_UPDATE_FREQ", 2},
-{ "TLE",     "AUTO_UPDATE_ACTION", 1},
-{ "TLE",     "LAST_UPDATE", 0},
-{ "LOG",     "CLEAN_AGE", 0},  /* 0 = Never clean */
-{ "LOG",     "LEVEL", 4}
+    { "SKY_AT_GLANCE", "COLOUR_01", 0x3c46c8},
+    { "SKY_AT_GLANCE", "COLOUR_02", 0x00500a},
+    { "SKY_AT_GLANCE", "COLOUR_03", 0xd5472b},
+    { "SKY_AT_GLANCE", "COLOUR_04", 0xd06b38},
+    { "SKY_AT_GLANCE", "COLOUR_05", 0xcf477a},
+    { "SKY_AT_GLANCE", "COLOUR_06", 0xbf041f},
+    { "SKY_AT_GLANCE", "COLOUR_07", 0x688522},
+    { "SKY_AT_GLANCE", "COLOUR_08", 0x0420bf},
+    { "SKY_AT_GLANCE", "COLOUR_09", 0xa304bf},
+    { "SKY_AT_GLANCE", "COLOUR_10", 0x04bdbf},
+    { "GLOBAL",  "WINDOW_POS_X", 0},
+    { "GLOBAL",  "WINDOW_POS_Y", 0},
+    { "GLOBAL",  "WINDOW_WIDTH", 700},
+    { "GLOBAL",  "WINDOW_HEIGHT", 700},
+    { "GLOBAL",  "HTML_BROWSER_TYPE", 0},
+    { "TLE",     "AUTO_UPDATE_FREQ", 2},
+    { "TLE",     "AUTO_UPDATE_ACTION", 1},
+    { "TLE",     "LAST_UPDATE", 0},
+    { "LOG",     "CLEAN_AGE", 0},  /* 0 = Never clean */
+    { "LOG",     "LEVEL", 4}
 };
 
 
@@ -213,8 +215,9 @@ sat_cfg_str_t sat_cfg_str[SAT_CFG_STR_NUM] = {
     { "GLOBAL", "DEFAULT_QTH", "sample.qth"},
     { "GLOBAL", "OPEN_MODULES", "Amateur"},
     { "GLOBAL", "HTML_BROWSER", NULL},
-    { "MODULES", "MAP_FILE", "nasa-topo_800.png"},
-    { "MODULES", "MAP_FONT", "Sans 10"},
+    { "MODULES", "GRID", "1;0;2;0;1;2;0;1;1;2;3;1;2;1;2"},
+    { "MODULES", "MAP_FILE", "nasa-bmng-07_1024.jpg"},
+    { "MODULES", "MAP_FONT", "Sans 8"},
     { "MODULES", "POLAR_FONT", "Sans 10"},
     { "TLE",     "SERVER", "http://www.celestrak.com/NORAD/elements/"},
     { "TLE",     "FILES", "amateur.txt;cubesat.txt;dmc.txt;education.txt;"\
@@ -304,8 +307,7 @@ guint sat_cfg_load        ()
  * This function saves the configuration data currently stored in
  * memory to the gpredict.cfg file.
  */
-guint
-        sat_cfg_save        ()
+guint sat_cfg_save        ()
 {
     gsize       length;
     gsize       written;
@@ -395,8 +397,7 @@ guint
  * is called again. This function should only be called when the
  * program exits.
  */
-void
-        sat_cfg_close        ()
+void sat_cfg_close        ()
 {
     if (config != NULL) {
         g_key_file_free (config);
@@ -447,8 +448,7 @@ gboolean
 }
 
 /** \brief Get default value of boolean parameter */
-gboolean
-        sat_cfg_get_bool_def (sat_cfg_bool_e param)
+gboolean sat_cfg_get_bool_def (sat_cfg_bool_e param)
 {
     gboolean value = FALSE;
 
@@ -471,8 +471,7 @@ gboolean
  * This function stores a boolean configuration value in the configuration
  * table.
  */
-void
-        sat_cfg_set_bool (sat_cfg_bool_e param, gboolean value)
+void sat_cfg_set_bool (sat_cfg_bool_e param, gboolean value)
 {
 
     if (param < SAT_CFG_BOOL_NUM) {
@@ -528,8 +527,7 @@ void
  *
  * Return a newly allocated gchar * which must be freed when no longer needed.
  */
-gchar *
-        sat_cfg_get_str (sat_cfg_str_e param)
+gchar *sat_cfg_get_str (sat_cfg_str_e param)
 {
     gchar    *value;
     GError   *error = NULL;
@@ -574,8 +572,7 @@ gchar *
  *
  * Returns a newly allocated gchar * which must be freed when no longer needed.
  */
-gchar *
-        sat_cfg_get_str_def (sat_cfg_str_e param)
+gchar *sat_cfg_get_str_def (sat_cfg_str_e param)
 {
     gchar *value;
 
@@ -595,8 +592,7 @@ gchar *
 
 /** \brief Store a str configuration value.
  */
-void
-        sat_cfg_set_str (sat_cfg_str_e param, const gchar *value)
+void sat_cfg_set_str (sat_cfg_str_e param, const gchar *value)
 {
 
     if (param < SAT_CFG_STR_NUM) {
@@ -631,8 +627,7 @@ void
 }
 
 
-void
-        sat_cfg_reset_str (sat_cfg_str_e param)
+void sat_cfg_reset_str (sat_cfg_str_e param)
 {
 
     if (param < SAT_CFG_STR_NUM) {
@@ -657,8 +652,7 @@ void
     }
 }
 
-gint
-        sat_cfg_get_int      (sat_cfg_int_e param)
+gint sat_cfg_get_int      (sat_cfg_int_e param)
 {
     gint      value = 0;
     GError   *error = NULL;
@@ -698,8 +692,7 @@ gint
 }
 
 
-gint
-        sat_cfg_get_int_def  (sat_cfg_int_e param)
+gint sat_cfg_get_int_def  (sat_cfg_int_e param)
 {
     gint   value = 0;
 
@@ -716,8 +709,7 @@ gint
 }
 
 
-void
-        sat_cfg_set_int      (sat_cfg_int_e param, gint value)
+void sat_cfg_set_int      (sat_cfg_int_e param, gint value)
 {
     if (param < SAT_CFG_INT_NUM) {
         
@@ -742,8 +734,7 @@ void
 }
 
 
-void
-        sat_cfg_reset_int    (sat_cfg_int_e param)
+void sat_cfg_reset_int    (sat_cfg_int_e param)
 {
     if (param < SAT_CFG_INT_NUM) {
         
