@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -84,6 +84,7 @@ typedef enum {
     SAT_CFG_INT_MAP_TICK_COL,         /*!< Tick labels colour. */
     SAT_CFG_INT_MAP_TRACK_COL,        /*!< Ground Track colour. */
     SAT_CFG_INT_MAP_TRACK_NUM,        /*!< Number of orbits to show ground track for */
+    SAT_CFG_INT_MAP_SHADOW_ALPHA,     /*!< Tranparency of shadow under satellite marker. */
     SAT_CFG_INT_POLAR_REFRESH,        /*!< Polar refresh rate (cycle). */
     SAT_CFG_INT_POLAR_ORIENTATION,    /*!< Orientation of the polar charts. */
     SAT_CFG_INT_POLAR_BGD_COL,        /*!< Polar view, background colour. */
@@ -95,6 +96,7 @@ typedef enum {
     SAT_CFG_INT_POLAR_INFO_COL,       /*!< Info colour. */
     SAT_CFG_INT_SINGLE_SAT_REFRESH,   /*!< Single-sat refresh rate (cycle). */
     SAT_CFG_INT_SINGLE_SAT_FIELDS,    /*!< Single-sat fields. */
+    SAT_CFG_INT_EVENT_LIST_REFRESH,   /*!< Event list refresh rate (cycle). */
     SAT_CFG_INT_PRED_MIN_EL,          /*!< Minimum elevation for passes. */
     SAT_CFG_INT_PRED_NUM_PASS,        /*!< Number of passes to predict. */
     SAT_CFG_INT_PRED_LOOK_AHEAD,      /*!< Look-ahead time limit in days. */ 
@@ -130,13 +132,13 @@ typedef enum {
 } sat_cfg_int_e;
 
 
-
 /** \brief Symbolic references for string config values. */
 typedef enum {
     SAT_CFG_STR_TIME_FORMAT = 0,/*!< Time format. */
     SAT_CFG_STR_DEF_QTH,        /*!< Default QTH file. */
     SAT_CFG_STR_OPEN_MODULES,   /*!< Open modules. */
     SAT_CFG_STR_WEB_BROWSER,    /*!< Web browser string. */
+    SAT_CFG_STR_MODULE_GRID,    /*!< The grid layout of the module */
     SAT_CFG_STR_MAP_FILE,       /*!< Map file (abs or rel). */
     SAT_CFG_STR_MAP_FONT,       /*!< Map font. */
     SAT_CFG_STR_POL_FONT,       /*!< Polar view font. */
