@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -47,27 +47,38 @@ static GtkWidget *create_transponder_table (guint catnum);
 static gchar *epoch_to_str     (sat_t *sat);
 
 
-/** \brief Show satellite info in a dialog 
+/** \brief Show satellite info in a dialog (callback)
  *  \param menuitem The menuitem from where the function is invoked.
  *  \param data Pointer to parent window or NULL.
  *
+ */
+void
+show_sat_info_menu_cb (GtkWidget *menuitem, gpointer data)
+{
+    sat_t     *sat;
+
+    sat = SAT(g_object_get_data (G_OBJECT (menuitem), "sat"));
+    show_sat_info(sat, data);
+}
+
+/** \brief Show satellite info in a dialog 
+ *  \param sat Pointer to the sat info.
+ *  \param data Pointer to parent window or NULL.
+ *
  * FIXME: see nice drawing at http://www.amsat.org/amsat-new/tools/keps_tutorial.php
  *
 */
 void
-show_sat_info (GtkWidget *menuitem, gpointer data)
+show_sat_info (sat_t *sat, gpointer data)
 {
     GtkWidget *dialog;
     GtkWidget *notebook;
     GtkWidget *table;
     GtkWidget *label;
     GtkWindow *toplevel = NULL;
-    sat_t     *sat;
     gchar     *str;
 
 
-    sat = SAT(g_object_get_data (G_OBJECT (menuitem), "sat"));
-
     if (data != NULL)
         toplevel = GTK_WINDOW (data);
 
@@ -328,8 +339,6 @@ show_sat_info (GtkWidget *menuitem, gpointer data)
 
     g_signal_connect (dialog, "response",
                 G_CALLBACK (gtk_widget_destroy), NULL);
-    g_signal_connect (dialog, "destroy",
-                G_CALLBACK (gtk_widget_destroyed), &dialog);
 
     gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), notebook);
     
@@ -345,7 +354,7 @@ show_sat_info (GtkWidget *menuitem, gpointer data)
                       fractional portion of one day, but...
 
     we now have the converted fields, tle->epoch_year, tle->epoch_day and tle->epoch_fod
-		      
+                
 */
 static gchar *
 epoch_to_str (sat_t *sat)
@@ -415,7 +424,7 @@ epoch_to_str (sat_t *sat)
 /** \brief Create transponder table. */
 static GtkWidget *create_transponder_table (guint catnum)
 {
-    GtkWidget *vbox,*label;
+    GtkWidget *vbox,*label,*swin;
     GSList    *trsplist = NULL;
     trsp_t    *trsp = NULL;
     guint      i,n;
@@ -424,7 +433,7 @@ static GtkWidget *create_transponder_table (guint catnum)
     
     trsplist = read_transponders (catnum);
     if (trsplist == NULL) {
-        vbox = gtk_label_new (_("No transponders"));
+        swin = gtk_label_new (_("No transponders"));
     }
     else {
         vbox = gtk_vbox_new (FALSE, 0);
@@ -498,8 +507,14 @@ static GtkWidget *create_transponder_table (guint catnum)
             }
         }
         free_transponders (trsplist);
+
+        /* pack into a scrolled window */
+        swin = gtk_scrolled_window_new (NULL,NULL);
+        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+        //gtk_container_add (GTK_CONTAINER (swin), vbox);
+        gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (swin), vbox);
     }
     
-    return vbox;
+    return swin;
 }
 
