@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -208,6 +208,8 @@ create_editor_widgets (radio_conf_t *conf)
     gtk_combo_box_append_text (GTK_COMBO_BOX (type), _("TX only"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (type), _("Simplex TRX"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (type), _("Duplex TRX"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (type), _("FT817/857/897 (auto)"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (type), _("FT817/857/897 (manual)"));
     gtk_combo_box_set_active (GTK_COMBO_BOX (type), RIG_TYPE_RX);
     g_signal_connect (type, "changed", G_CALLBACK (type_changed), NULL);
     gtk_widget_set_tooltip_markup (type,
@@ -215,17 +217,24 @@ create_editor_widgets (radio_conf_t *conf)
                     "If <i>Monitor PTT status</i> is checked the doppler tuning "\
                     "will be suspended while PTT is ON (manual TX). "\
                     "If not, the controller will always perform doppler tuning and "\
-                    "you cannot use the same RIG for uplink.\n"\
+                    "you cannot use the same RIG for uplink.\n\n"\
                     "<b>TX only:</b>  The radio shall only be used for uplink. "\
                     "If <i>Monitor PTT status</i> is checked the doppler tuning "\
-                    "will be suspended while PTT is OFF (manual RX).\n"\
+                    "will be suspended while PTT is OFF (manual RX).\n\n"\
                     "<b>Simplex TRX:</b>  The radio should be used for both up- and downlink "\
                     "but in simplex mode only. This option requires that the PTT status "\
                     "is monitored (otherwise gpredict cannot know whether to tune the "\
-                    "RX or the TX).\n"\
+                    "RX or the TX).\n\n"\
                     "<b>Duplex:</b>  The radio is a full duplex radio, such as the IC910H. "\
                     "Gpredict will be continuously tuning both uplink and downlink "\
-                    "simultaneously and not care about PTT setting."));
+                    "simultaneously and not care about PTT setting.\n\n"\
+                    "<b>FT817/857/897 (auto):</b> This is a special mode that can be used with "\
+                    "YAESU FT-817, 857 and 897 radios. These radios do not allow computer "\
+                    "control while in TX mode. Therefore, TX Doppler correction is applied "\
+                    "while the radio is in RX mode by toggling between VFO A/B.\n\n"\
+                    "<b>FT817/857/897 (manual):</b> This is similar to the previous mode except "\
+                    "that switching to TX is done by pressing the SPACE key on the keyboard. "\
+                    "Gpredict will then update the TX Doppler before actually switching to TX."));
     gtk_table_attach_defaults (GTK_TABLE (table), type, 1, 3, 3, 4);
     
     /* ptt */
@@ -264,12 +273,12 @@ create_editor_widgets (radio_conf_t *conf)
     gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 0);
     g_signal_connect (vfo, "changed", G_CALLBACK (vfo_changed), NULL);
     gtk_widget_set_tooltip_markup (vfo,
-    							   _("Select which VFO to use for uplink and downlink. "\
-    							     "This setting is used for full-duplex radios only, "\
-    							     "such as the IC-910H, FT-847 and the TS-2000.\n\n"\
-    							     "<b>IC-910H:</b> MAIN\342\206\221 / SUB\342\206\223\n"\
-    							     "<b>FT-847:</b> SUB\342\206\221 / MAIN\342\206\223\n"\
-    							     "<b>TS-2000:</b> B\342\206\221 / A\342\206\223"));
+                                          _("Select which VFO to use for uplink and downlink. "\
+                                            "This setting is used for full-duplex radios only, "\
+                                            "such as the IC-910H, FT-847 and the TS-2000.\n\n"\
+                                            "<b>IC-910H:</b> MAIN\342\206\221 / SUB\342\206\223\n"\
+                                            "<b>FT-847:</b> SUB\342\206\221 / MAIN\342\206\223\n"\
+                                            "<b>TS-2000:</b> B\342\206\221 / A\342\206\223"));
     gtk_table_attach_defaults (GTK_TABLE (table), vfo, 1, 3, 5, 6);
         
     /* Downconverter LO frequency */
@@ -343,14 +352,14 @@ update_widgets (radio_conf_t *conf)
     
     /* vfo up/down */
     if (conf->type == RIG_TYPE_DUPLEX) {
-    	if (conf->vfoUp == VFO_MAIN)
-    		gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 1);
+         if (conf->vfoUp == VFO_MAIN)
+              gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 1);
         else if (conf->vfoUp == VFO_SUB)
-    		gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 2);
+              gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 2);
         else if (conf->vfoUp == VFO_A)
-    		gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 3);
-    	else
-    		gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 4);
+              gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 3);
+         else
+              gtk_combo_box_set_active (GTK_COMBO_BOX (vfo), 4);
     }
 
     /* lo down in MHz */
@@ -422,33 +431,33 @@ apply_changes         (radio_conf_t *conf)
     
     /* vfo up/down */
     if (conf->type == RIG_TYPE_DUPLEX) {
-		switch (gtk_combo_box_get_active (GTK_COMBO_BOX (vfo))) {
-		
-		case 1:
-			conf->vfoUp = VFO_MAIN;
-			conf->vfoDown = VFO_SUB;
-			break;    	
-		
-		case 2:
-			conf->vfoUp = VFO_SUB;
-			conf->vfoDown = VFO_MAIN;
-			break;
-		
-		case 3:
-			conf->vfoUp = VFO_A;
-			conf->vfoDown = VFO_B;
-			break;    	
-		
-		case 4:
-			conf->vfoUp = VFO_B;
-			conf->vfoDown = VFO_A;
-			break;    	
-		
-		default:
-			conf->vfoUp = VFO_MAIN;
-			conf->vfoDown = VFO_SUB;
-			break;    	
-		}
+          switch (gtk_combo_box_get_active (GTK_COMBO_BOX (vfo))) {
+          
+          case 1:
+               conf->vfoUp = VFO_MAIN;
+               conf->vfoDown = VFO_SUB;
+               break;         
+          
+          case 2:
+               conf->vfoUp = VFO_SUB;
+               conf->vfoDown = VFO_MAIN;
+               break;
+          
+          case 3:
+               conf->vfoUp = VFO_A;
+               conf->vfoDown = VFO_B;
+               break;         
+          
+          case 4:
+               conf->vfoUp = VFO_B;
+               conf->vfoDown = VFO_A;
+               break;         
+          
+          default:
+               conf->vfoUp = VFO_MAIN;
+               conf->vfoDown = VFO_SUB;
+               break;         
+          }
     }
 
     return TRUE;
@@ -523,12 +532,18 @@ name_changed          (GtkWidget *widget, gpointer data)
 static void
 type_changed (GtkWidget *widget, gpointer data)
 {
-	/* PTT consistency */    
+     /* PTT consistency */    
     if (gtk_combo_box_get_active (GTK_COMBO_BOX (widget)) == RIG_TYPE_TRX) {
         if (gtk_combo_box_get_active (GTK_COMBO_BOX (ptt)) == PTT_TYPE_NONE) {
             gtk_combo_box_set_active (GTK_COMBO_BOX (ptt), PTT_TYPE_CAT);
         }
     }
+
+    if ((gtk_combo_box_get_active (GTK_COMBO_BOX (widget)) == RIG_TYPE_TOGGLE_AUTO) ||
+        (gtk_combo_box_get_active (GTK_COMBO_BOX (widget)) == RIG_TYPE_TOGGLE_MAN)) {
+        gtk_combo_box_set_active (GTK_COMBO_BOX (ptt), PTT_TYPE_CAT);
+    }
+
     
     /* VFO consistency */
     if (gtk_combo_box_get_active (GTK_COMBO_BOX (widget)) == RIG_TYPE_DUPLEX) {
