@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2010  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -52,6 +52,10 @@ static GtkWidget    *create_buttons        (void);
 static void add_cb    (GtkWidget *button, gpointer data);
 static void edit_cb   (GtkWidget *button, gpointer data);
 static void delete_cb (GtkWidget *button, gpointer data);
+static void row_activated_cb (GtkTreeView       *tree_view,
+                              GtkTreePath       *path,
+                              GtkTreeViewColumn *column,
+                              gpointer           user_data);
 
 static void render_name (GtkTreeViewColumn *col,
                          GtkCellRenderer   *renderer,
@@ -217,6 +221,7 @@ static void create_rig_list ()
                                                      NULL);
     gtk_tree_view_insert_column (GTK_TREE_VIEW (riglist), column, -1);
 
+    g_signal_connect (riglist, "row-activated", G_CALLBACK (row_activated_cb), riglist);
 }
 
 
@@ -245,6 +250,7 @@ static GtkTreeModel *create_and_fill_model ()
                                     G_TYPE_DOUBLE     // LO UO
                                    );
 
+     gtk_tree_sortable_set_sort_column_id( GTK_TREE_SORTABLE(liststore),RIG_LIST_COL_NAME,GTK_SORT_ASCENDING);
     /* open configuration directory */
     dirname = get_hwconf_dir ();
     
@@ -253,7 +259,7 @@ static GtkTreeModel *create_and_fill_model ()
         /* read each .rig file */
         while ((filename = g_dir_read_name (dir))) {
             
-            if (g_strrstr (filename, ".rig")) {
+            if (g_str_has_suffix (filename, ".rig")) {
                 
                 vbuff = g_strsplit (filename, ".rig", 0);
                 conf.name = g_strdup (vbuff[0]);
@@ -396,7 +402,7 @@ void sat_pref_rig_ok     ()
         /* read each .rig file */
         while ((filename = g_dir_read_name (dir))) {
 
-            if (g_strrstr (filename, ".rig")) {
+            if (g_str_has_suffix (filename, ".rig")) {
 
                 buff = g_strconcat (dirname, G_DIR_SEPARATOR_S, filename, NULL);
                 g_remove (buff);
@@ -645,6 +651,14 @@ static void delete_cb (GtkWidget *button, gpointer data)
     }
 }
 
+static void row_activated_cb (GtkTreeView       *tree_view,
+                              GtkTreePath       *path,
+                              GtkTreeViewColumn *column,
+                              gpointer           user_data)
+{
+    edit_cb (editbutton, NULL);
+}
+
 
 /** \brief Render configuration name.
  * \param col Pointer to the tree view column.
@@ -698,25 +712,33 @@ static void render_type (GtkTreeViewColumn *col,
     gtk_tree_model_get (model, iter, coli, &type, -1);
 
     switch (type) {
-        case RIG_TYPE_RX:
-            g_object_set (renderer, "text", _("RX only"), NULL);
-            break;
-            
-        case RIG_TYPE_TX:
-            g_object_set (renderer, "text", _("TX only"), NULL);
-            break;
+    case RIG_TYPE_RX:
+        g_object_set (renderer, "text", _("RX only"), NULL);
+        break;
 
-        case RIG_TYPE_TRX:
-            g_object_set (renderer, "text", _("RX + TX"), NULL);
-            break;
+    case RIG_TYPE_TX:
+        g_object_set (renderer, "text", _("TX only"), NULL);
+        break;
 
-        case RIG_TYPE_DUPLEX:
-            g_object_set (renderer, "text", _("Duplex"), NULL);
-            break;
+    case RIG_TYPE_TRX:
+        g_object_set (renderer, "text", _("RX + TX"), NULL);
+        break;
 
-        default:
-            g_object_set (renderer, "text", _("ERROR"), NULL);
-            break;
+    case RIG_TYPE_DUPLEX:
+        g_object_set (renderer, "text", _("Duplex"), NULL);
+        break;
+
+    case RIG_TYPE_TOGGLE_AUTO:
+        g_object_set (renderer, "text", _("FT817/857/897 (auto)"), NULL);
+        break;
+
+    case RIG_TYPE_TOGGLE_MAN:
+        g_object_set (renderer, "text", _("FT817/857/897 (man)"), NULL);
+        break;
+
+    default:
+        g_object_set (renderer, "text", _("ERROR"), NULL);
+        break;
     }
     
 }
@@ -838,6 +860,3 @@ static void render_vfo (GtkTreeViewColumn *col,
     g_free (buff);
 }
 
-
-
-
