@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2010  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -54,6 +54,10 @@ static GtkWidget    *create_buttons        (void);
 static void add_cb    (GtkWidget *button, gpointer data);
 static void edit_cb   (GtkWidget *button, gpointer data);
 static void delete_cb (GtkWidget *button, gpointer data);
+static void row_activated_cb (GtkTreeView       *tree_view,
+                              GtkTreePath       *path,
+                              GtkTreeViewColumn *column,
+                              gpointer           user_data);
 
 static void render_angle (GtkTreeViewColumn *col,
                           GtkCellRenderer   *renderer,
@@ -185,6 +189,8 @@ static void create_rot_list ()
                                              GUINT_TO_POINTER(ROT_LIST_COL_AZTYPE),
                                              NULL);
     gtk_tree_view_insert_column (GTK_TREE_VIEW (rotlist), column, -1);
+
+    g_signal_connect (rotlist, "row-activated", G_CALLBACK (row_activated_cb), NULL);
 }
 
 
@@ -211,7 +217,7 @@ static GtkTreeModel *create_and_fill_model ()
                                     G_TYPE_DOUBLE,    // Max El
                                     G_TYPE_INT        // Az type
                                    );
-
+     gtk_tree_sortable_set_sort_column_id( GTK_TREE_SORTABLE(liststore),ROT_LIST_COL_NAME,GTK_SORT_ASCENDING);
     /* open configuration directory */
     dirname = get_hwconf_dir ();
     
@@ -220,7 +226,7 @@ static GtkTreeModel *create_and_fill_model ()
         /* read each .rot file */
         while ((filename = g_dir_read_name (dir))) {
             
-            if (g_strrstr (filename, ".rot")) {
+            if (g_str_has_suffix (filename, ".rot")) {
                 
                 vbuff = g_strsplit (filename, ".rot", 0);
                 conf.name = g_strdup (vbuff[0]);
@@ -360,7 +366,7 @@ void sat_pref_rot_ok     ()
         /* read each .rot file */
         while ((filename = g_dir_read_name (dir))) {
 
-            if (g_strrstr (filename, ".rot")) {
+            if (g_str_has_suffix (filename, ".rot")) {
 
                 buff = g_strconcat (dirname, G_DIR_SEPARATOR_S, filename, NULL);
                 g_remove (buff);
@@ -603,6 +609,14 @@ static void delete_cb (GtkWidget *button, gpointer data)
     }
 }
 
+static void row_activated_cb (GtkTreeView       *tree_view,
+                              GtkTreePath       *path,
+                              GtkTreeViewColumn *column,
+                              gpointer           user_data)
+{
+    edit_cb (editbutton, NULL);
+}
+
 /** \brief Render an angle.
  * \param col Pointer to the tree view column.
  * \param renderer Pointer to the renderer.
@@ -667,6 +681,3 @@ static void render_aztype (GtkTreeViewColumn *col,
     g_free (text);
 }
 
-
-
-
