@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
@@ -29,7 +29,7 @@
 #define TIME_TOOLS_H 1
 
 gdouble  get_current_daynum  (void);
-long     get_daynum_from_dmy (int d, int m, int y);
+//long     get_daynum_from_dmy (int d, int m, int y);
 #endif
 
 
