@@ -1,8 +1,9 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
     Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2009 Charles Suprin AA1VS.
 
     Authors: Alexandru Csete <oz9aec@gmail.com>
 
@@ -45,12 +46,17 @@
    e.g. user starts update from menubar while automatic
    update is in progress
 */
-static gboolean tle_in_progress = FALSE;
-
+/* static gboolean tle_in_progress = FALSE; */
+/* Replace flag with lock */
+/* http://library.gnome.org/devel/glib/unstable/glib-Threads.html */
+static GStaticMutex tle_in_progress = G_STATIC_MUTEX_INIT ;
+static GStaticMutex tle_file_in_progress = G_STATIC_MUTEX_INIT ;
 
 /* private function prototypes */
 static size_t  my_write_func (void *ptr, size_t size, size_t nmemb, FILE *stream);
 static gint    read_fresh_tle (const gchar *dir, const gchar *fnam, GHashTable *data);
+static gboolean is_tle_file (const gchar *dir, const gchar *fnam);
+
 
 static void    update_tle_in_file (const gchar *ldname,
                                    const gchar *fname,
@@ -118,7 +124,13 @@ void tle_update_from_files (const gchar *dir, const gchar *filter,
     gdouble      fraction = 0.0;
     gdouble      start = 0.0;
 
+    if (g_static_mutex_trylock(&tle_file_in_progress)==FALSE) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: A TLE update process is already running. Aborting."),
+                     __FUNCTION__);
 
+        return;
+    }
 
     /* create hash table */
     data = g_hash_table_new_full (g_int_hash, g_int_equal, g_free, free_new_tle);
@@ -149,28 +161,32 @@ void tle_update_from_files (const gchar *dir, const gchar *filter,
     }
     else {
 
-        /* read fresh tle files into memory */
+        /* scan directory for tle files */
         while ((fnam = g_dir_read_name (cache_dir)) != NULL) {
 
-            /* status message */
-            if (!silent && (label1 != NULL)) {
-                text = g_strdup_printf (_("Reading data from %s"), fnam);
-                gtk_label_set_text (GTK_LABEL (label1), text);
-                g_free (text);
-
-
-                /* Force the drawing queue to be processed otherwise there will
-                    not be any visual feedback, ie. frozen GUI
-                    - see Gtk+ FAQ http://www.gtk.org/faq/#AEN602
-                */
-                while (g_main_context_iteration (NULL, FALSE));
-
-                /* give user a chance to follow progress */
-                g_usleep (G_USEC_PER_SEC / 100);
+            /* check that we got a TLE file */
+            if (is_tle_file(dir, fnam)) {
+                
+                /* status message */
+                if (!silent && (label1 != NULL)) {
+                    text = g_strdup_printf (_("Reading data from %s"), fnam);
+                    gtk_label_set_text (GTK_LABEL (label1), text);
+                    g_free (text);
+    
+    
+                    /* Force the drawing queue to be processed otherwise there will
+                        not be any visual feedback, ie. frozen GUI
+                        - see Gtk+ FAQ http://www.gtk.org/faq/#AEN602
+                    */
+                    while (g_main_context_iteration (NULL, FALSE));
+    
+                    /* give user a chance to follow progress */
+                    g_usleep (G_USEC_PER_SEC / 100);
+                }
+    
+                /* now, do read the fresh data */
+                num = read_fresh_tle (dir, fnam, data);
             }
-
-            /* now, do read the fresh data */
-            num = read_fresh_tle (dir, fnam, data);
             
             if (num < 1) {
                 sat_log_log (SAT_LOG_LEVEL_ERROR,
@@ -229,7 +245,7 @@ void tle_update_from_files (const gchar *dir, const gchar *filter,
             num = 0;
             while ((fnam = g_dir_read_name (loc_dir)) != NULL) {
                 /* only consider .sat files */
-                if (g_strrstr (fnam, ".sat")) {
+                if (g_str_has_suffix (fnam, ".sat")) {
                     num++;
                 }
             }
@@ -239,7 +255,7 @@ void tle_update_from_files (const gchar *dir, const gchar *filter,
             /* update TLE files one by one */
             while ((fnam = g_dir_read_name (loc_dir)) != NULL) {
                 /* only consider .sat files */
-                if (g_strrstr (fnam, ".sat")) {
+                if (g_str_has_suffix (fnam, ".sat")) {
 
                     /* clear stat bufs */
                     updated_tmp = 0;
@@ -348,6 +364,7 @@ void tle_update_from_files (const gchar *dir, const gchar *filter,
     /* destroy hash tables */
     g_hash_table_destroy (data);
 
+    g_static_mutex_unlock(&tle_file_in_progress);
 }
 
 
@@ -509,13 +526,18 @@ void tle_update_from_network (gboolean   silent,
     GError      *err = NULL;
     guint        success = 0; /* no. of successfull downloads */ 
 
-
     /* bail out if we are already in an update process */
-    if (tle_in_progress)
+    /*if (tle_in_progress)*/
+    if (g_static_mutex_trylock(&tle_in_progress)==FALSE) {
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: A TLE update process is already running. Aborting."),
+                     __FUNCTION__);
+
         return;
+    }
 
 
-    tle_in_progress = TRUE;
+    /*tle_in_progress = TRUE;*/
 
     /* get server, proxy, and list of files */
     server = sat_cfg_get_str (SAT_CFG_STR_TLE_SERVER);
@@ -570,7 +592,7 @@ void tle_update_from_network (gboolean   silent,
                 while (g_main_context_iteration (NULL, FALSE));
             }
 
-            /* creae local cache file */
+            /* create local cache file */
             userconfdir = get_user_conf_dir ();
             locfile = g_strconcat (userconfdir, G_DIR_SEPARATOR_S,
                                    "satdata", G_DIR_SEPARATOR_S,
@@ -621,10 +643,19 @@ void tle_update_from_network (gboolean   silent,
 
         /* continue update if we have fetched at least one file */
         if (success > 0) {
+            sat_log_log (SAT_LOG_LEVEL_MSG,
+                         _("%s: Fetched %d files from network; updating..."),
+                         __FUNCTION__, success);
             /* call update_from_files */
             cache = sat_file_name ("cache");
             tle_update_from_files (cache, NULL, silent, progress, label1, label2);
             g_free (cache);
+
+        }
+        else {
+            sat_log_log (SAT_LOG_LEVEL_ERROR,
+                         _("%s: Could not fetch any new TLE files from network; aborting..."),
+                         __FUNCTION__);
         }
 
     }
@@ -664,7 +695,8 @@ void tle_update_from_network (gboolean   silent,
     g_free (cache);
 
     /* clear busy flag */
-    tle_in_progress = FALSE;
+    /* tle_in_progress = FALSE; */
+    g_static_mutex_unlock(&tle_in_progress);
 
 }
 
@@ -686,12 +718,45 @@ static size_t my_write_func (void *ptr, size_t size, size_t nmemb, FILE *stream)
 }
 
 
+/** \brief Check whether file is TLE file.
+ *  \param dir The directory.
+ *  \param fnam The file name.
+ * 
+ * This function checks whether the file with path dir/fnam is a potential
+ * TLE file. Checks performed:
+ *   - It is a real file
+ *   - suffix is .txt or .tle
+ */
+static gboolean is_tle_file (const gchar *dir, const gchar *fnam)
+{
+    gchar    *path;
+    gchar    *fname_lower;
+    gboolean  fileIsOk = FALSE;
+    
+    path = g_strconcat (dir, G_DIR_SEPARATOR_S, fnam, NULL);
+    fname_lower=g_ascii_strdown(fnam,-1);
+    
+    if (g_file_test (path, G_FILE_TEST_IS_REGULAR) && 
+        (g_str_has_suffix(fname_lower, ".tle") || g_str_has_suffix(fname_lower, ".txt")))
+    {
+        fileIsOk = TRUE;      
+    }
+    g_free (fname_lower);
+    g_free (path);
+    
+    return fileIsOk;
+}
+
 
 /** \brief Read fresh TLE data into hash table.
  *  \param dir The directory to read from.
  *  \param fnam The name of the file to read from.
  *  \param fresh_data Hash table where the data should be stored.
  *  \return The number of satellites successfully read.
+ * 
+ * This function will read fresh TLE data from local files into memory.
+ * If there is a saetllite category (.cat file) with the same name as the
+ * input file it will also update the satellites in that category.
  */
 static gint read_fresh_tle (const gchar *dir, const gchar *fnam, GHashTable *data)
 {
@@ -710,6 +775,7 @@ static gint read_fresh_tle (const gchar *dir, const gchar *fnam, GHashTable *dat
     gchar     *catname, *catpath, *buff, **buffv;
     FILE      *catfile;
     gchar      category[80];
+    gboolean   catsync = FALSE; /* whether .cat file should be synced */
 
 
 
@@ -728,16 +794,35 @@ static gint read_fresh_tle (const gchar *dir, const gchar *fnam, GHashTable *dat
 
         /* read category name for catfile */
         catfile = g_fopen (catpath, "r");
-        b = fgets (category, 80, catfile);
-        fclose (catfile);
+        if (catfile!=NULL) {
+            b = fgets (category, 80, catfile);
+            fclose (catfile);
+            catsync = TRUE;
+        }
+        else {
+            /* There is no category with this name (could be update from custom file) */
+            sat_log_log (SAT_LOG_LEVEL_MSG,
+                         _("%s:%s: There is no category called %s"),
+                         __FILE__, __FUNCTION__, fnam);
+        }
 
         /* reopen a new catfile and write category name */
-        catfile = g_fopen (catpath, "w");
-        g_free (catpath);
-        fputs (category, catfile);
-
-        /* .cat file now contains the category name;
-           satellite catnums will be added during update in the while loop */
+        if (catsync) {
+            catfile = g_fopen (catpath, "w");
+            if (catfile != NULL) {
+                fputs (category, catfile);
+            }
+            else {
+                catsync = FALSE;
+                sat_log_log (SAT_LOG_LEVEL_ERROR,
+                             _("%s:%s: Could not reopen .cat file while reading TLE from %s"),
+                             __FILE__, __FUNCTION__, fnam);
+            }
+            
+            /* .cat file now contains the category name;
+               satellite catnums will be added during update in the while loop */
+        }
+        
 
         /* read 3 lines at a time */
         while (fgets (tle_str[0], 80, fp)) {
@@ -763,16 +848,13 @@ static gint read_fresh_tle (const gchar *dir, const gchar *fnam, GHashTable *dat
                              __FILE__, __FUNCTION__, catnr);
             }
             else {
-                /* DATA OK, phew... */
-                /* 				sat_log_log (SAT_LOG_LEVEL_DEBUG, */
-                /* 						     _("%s: Good data for %d"), */
-                /* 						     __FUNCTION__, */
-                /* 						     catnr); */
 
-                /* store catalog number in catfile */
-                buff = g_strdup_printf ("%d\n", catnr);
-                fputs (buff, catfile);
-                g_free (buff);
+                if (catsync) {
+                    /* store catalog number in catfile */
+                    buff = g_strdup_printf ("%d\n", catnr);
+                    fputs (buff, catfile);
+                    g_free (buff);
+                }
 
                 /* add data to hash table */
                 key = g_try_new0 (guint, 1);
@@ -785,12 +867,12 @@ static gint read_fresh_tle (const gchar *dir, const gchar *fnam, GHashTable *dat
                     ntle = g_try_new (new_tle_t, 1);
                     ntle->catnum = catnr;
                     ntle->epoch = tle.epoch;
-                    ntle->satname = g_strdup (tle_str[0]);
+                    ntle->satname = g_strdup (g_strchomp(tle_str[0]));
                     ntle->line1   = g_strdup (tle_str[1]);
                     ntle->line2   = g_strdup (tle_str[2]);
                     ntle->srcfile = g_strdup (fnam);
                     ntle->isnew   = TRUE; /* flag will be reset when using data */
-                    
+
 
                     g_hash_table_insert (data, key, ntle);
                     retcode++;
@@ -802,8 +884,12 @@ static gint read_fresh_tle (const gchar *dir, const gchar *fnam, GHashTable *dat
 
         }
 
-        /* close category file */
-        fclose (catfile);
+        if (catsync) {
+            /* close category file */
+            fclose (catfile);
+        }
+
+        g_free (catpath);
 
         /* close input TLE file */
         fclose (fp);
